//
// Programmer:    Max Mathews <mvm@ccrma.stanford.edu>
// Modified by:   Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Fri Jan 12 12:44:12 PST 1996 
// Last Modified: Tue Jun 22 20:24:38 PDT 1999
// Filename:      ...improv/doc/examples/batonImprov/runs/runs.cpp
// Syntax:        C++; batonImprov 2.0
//
// Description:   runs -- play a sequence of notes pitch follows x1, y1p->tempo
//

#include "batonImprov.h"

#define RUNS_ON 1
#define RUNS_OFF 0

int  nextnotetime = 0;     // time in milliseconds for next note
int  keyno = 0;            // pitch to play on the synthesizer
int  status = RUNS_OFF;    // boolean to determine when to play notes


/***************** Beginning of user functions ****************************/


/*---------------- Documentation functions -------------------------------*/

void description(void) {
   cout
   << "______________________________________________________________ \n"
   << "| Description:                                                |\n"
   << "|    A sequence of notes follows baton 1 around the surface.  |\n"
   << "| Hit the surface with baton 1 to start the runs.  Lift       |\n"
   << "| baton 1 or hit with baton 2 to stop the runs.               |\n"
   << "---------------------------------------------------------------\n"
   << endl;
}

void programhelp(void) {
   cout
   << ">                                                              \n"
   << "> Baton 1:                                                     \n"
   << ">   trig: Starts playing of runs                               \n"
   << ">    x1p: Pitch of notes                                       \n"
   << ">    y1p: Tempo                                                \n"
   << "> Baton 2:                                                     \n"
   << ">   trig: Stops playing of runs                                \n"
   << ">                                                              \n"
   << ">   +b14: Command mode                                         \n"
   << ">   +b15: This help screen                                     \n"
   << ">                                                              \n"
   << endl;
   ;
}


/*---------------- Initialization functions ------------------------------*/

void initialization(void) {
   description();
}


/*---------------- Main loop functions -----------------------------------*/

void mainloopalgorithms(void) {
   // if it is time for a new note and baton 1 is near the surface:
   if (status == ON && t_time >= nextnotetime && baton.z1p > 70) {
      nextnotetime = t_time + 180 - baton.y1p;

      synth.play(0, keyno, 0);			// turn off previous note
      if (keyno < baton.x1p) keyno += 3;
      else keyno -= 3;

      if (keyno > 127) keyno = 127;
      if (keyno < 0) keyno = 0;

      synth.play(0, keyno, 127);		// play new keyno
   } 
}


/*---------------- Trigger response functions ----------------------------*/

void stick1trig(void) { cout << "Baton 1 triggered\n"; status = ON; }
void stick2trig(void) { cout << "Baton 2 triggered\n"; status = OFF; }
void b14plustrig(void) { }
void b15plustrig(void) { }
void b14minusuptrig(void) { }
void b14minusdowntrig(void) { }
void b15minusuptrig(void) { }
void b15minusdowntrig(void) { }
void keyboardchar(int key) { }


/*---------------- Actions to take just before leaving program -----------*/

void finishup(void) { }

/***************** End of user functions **********************************/

