(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    102473,       3479]*)
(*NotebookOutlinePosition[    103130,       3503]*)
(*  CellTagsIndexPosition[    103086,       3499]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["First-Order Allpass Filter Characteristics", "Title"],

Cell[CellGroupData[{

Cell["Frequency response", "Subsection"],

Cell[BoxData[
    \(H[z_, \ g_]\  := \ 
      \((z^\(-1\)\  - \ Conjugate[g])\)\ /\ \((1\  - \ g\ z^\(-1\))\)\)], 
  "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude response", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Abs[H[w, \ 0.5]], \ {w, \ 0, \ 2  Pi}, \ PlotRange -> {0, \ 2}]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.151576 0 0.309017 [
[.17539 -0.0125 -3 -9 ]
[.17539 -0.0125 3 0 ]
[.32696 -0.0125 -3 -9 ]
[.32696 -0.0125 3 0 ]
[.47854 -0.0125 -3 -9 ]
[.47854 -0.0125 3 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -3 -9 ]
[.78169 -0.0125 3 0 ]
[.93327 -0.0125 -3 -9 ]
[.93327 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(1)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(2)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(3)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(4)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(5)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(6)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.04011 .30902 L
.04141 .30902 L
.04262 .30902 L
.04386 .30902 L
.04456 .30902 L
.04521 .30902 L
.0464 .30902 L
.04765 .30902 L
.04878 .30902 L
.04983 .30902 L
.05097 .30902 L
.05221 .30902 L
.0529 .30902 L
.05354 .30902 L
.0548 .30902 L
.05594 .30902 L
.05715 .30902 L
.06244 .30902 L
.0637 .30902 L
.06487 .30902 L
.06608 .30902 L
.06677 .30902 L
.06742 .30902 L
.06812 .30902 L
.06877 .30902 L
.06946 .30902 L
.07021 .30902 L
.07277 .30902 L
.07404 .30902 L
.07523 .30902 L
.07646 .30902 L
.07712 .30902 L
.07782 .30902 L
.07907 .30902 L
.08025 .30902 L
.08131 .30902 L
Mistroke
.08247 .30902 L
.08319 .30902 L
.08398 .30902 L
.08471 .30902 L
.08539 .30902 L
.08803 .30902 L
.09091 .30902 L
.09161 .30902 L
.09236 .30902 L
.09318 .30902 L
.09394 .30902 L
.09466 .30902 L
.09532 .30902 L
.09604 .30902 L
.0968 .30902 L
.09809 .30902 L
.09951 .30902 L
.10077 .30902 L
.10148 .30902 L
.10213 .30902 L
.10332 .30902 L
.10458 .30902 L
.10582 .30902 L
.10652 .30902 L
.10716 .30902 L
.10835 .30902 L
.1096 .30902 L
.11072 .30902 L
.11177 .30902 L
.11291 .30902 L
.11415 .30902 L
.11547 .30902 L
.11673 .30902 L
.11795 .30902 L
.11908 .30902 L
.12029 .30902 L
.12099 .30902 L
.12164 .30902 L
.12295 .30902 L
.12368 .30902 L
.12436 .30902 L
.12543 .30902 L
.12657 .30902 L
.12765 .30902 L
.12863 .30902 L
.12979 .30902 L
.13104 .30902 L
.13222 .30902 L
.13331 .30902 L
.13444 .30902 L
Mistroke
.13549 .30902 L
.13665 .30902 L
.13789 .30902 L
.13919 .30902 L
.14042 .30902 L
.14153 .30902 L
.14274 .30902 L
.16407 .30902 L
.18341 .30902 L
.19309 .30902 L
.19437 .30902 L
.19508 .30902 L
.19573 .30902 L
.19699 .30902 L
.19819 .30902 L
.19942 .30902 L
.20011 .30902 L
.20076 .30902 L
.2014 .30902 L
.20212 .30902 L
.20357 .30902 L
.20603 .30902 L
.2067 .30902 L
.20741 .30902 L
.20867 .30902 L
.20986 .30902 L
.21096 .30902 L
.21217 .30902 L
.21346 .30902 L
.22256 .30902 L
.22754 .30902 L
.23005 .30902 L
.23074 .30902 L
.23147 .30902 L
.23217 .30902 L
.23281 .30902 L
.2335 .30902 L
.23423 .30902 L
.23503 .30902 L
.23577 .30902 L
.23654 .30902 L
.23725 .30902 L
.23789 .30902 L
.23859 .30902 L
.23923 .30902 L
.23994 .30902 L
.24137 .30902 L
.24392 .30902 L
.24896 .30902 L
.2496 .30902 L
Mistroke
.25029 .30902 L
.25104 .30902 L
.25173 .30902 L
.25298 .30902 L
.25369 .30902 L
.25435 .30902 L
.25563 .30902 L
.2568 .30902 L
.25944 .30902 L
.26407 .30902 L
.28305 .30902 L
.28434 .30902 L
.28506 .30902 L
.28573 .30902 L
.28695 .30902 L
.28825 .30902 L
.28896 .30902 L
.28963 .30902 L
.29037 .30902 L
.29116 .30902 L
.29186 .30902 L
.29253 .30902 L
.29379 .30902 L
.295 .30902 L
.29627 .30902 L
.29737 .30902 L
.29857 .30902 L
.30377 .30902 L
.305 .30902 L
.30631 .30902 L
.30755 .30902 L
.30868 .30902 L
.30995 .30902 L
.31115 .30902 L
.31245 .30902 L
.31318 .30902 L
.31386 .30902 L
.31489 .30902 L
.316 .30902 L
.31721 .30902 L
.31835 .30902 L
.31962 .30902 L
.32084 .30902 L
.32192 .30902 L
.32311 .30902 L
.32379 .30902 L
.32452 .30902 L
.32522 .30902 L
.32586 .30902 L
.32707 .30902 L
Mistroke
.32835 .30902 L
.33101 .30902 L
.33174 .30902 L
.33252 .30902 L
.33325 .30902 L
.33393 .30902 L
.33521 .30902 L
.3364 .30902 L
.3377 .30902 L
.33836 .30902 L
.33908 .30902 L
.34029 .30902 L
.3416 .30902 L
.34283 .30902 L
.34396 .30902 L
.34524 .30902 L
.34645 .30902 L
.34754 .30902 L
.34871 .30902 L
.34999 .30902 L
.35064 .30902 L
.35135 .30902 L
.35261 .30902 L
.35378 .30902 L
.35496 .30902 L
.35609 .30902 L
.35709 .30902 L
.35819 .30902 L
.35938 .30902 L
.36064 .30902 L
.36172 .30902 L
.36291 .30902 L
.36422 .30902 L
.36487 .30902 L
.36559 .30902 L
.36805 .30902 L
.37359 .30902 L
.38362 .30902 L
.4032 .30902 L
.40884 .30902 L
.41018 .30902 L
.41086 .30902 L
.41161 .30902 L
.41293 .30902 L
.41417 .30902 L
.41537 .30902 L
.41647 .30902 L
.41774 .30902 L
.41895 .30902 L
.42414 .30902 L
Mistroke
.42529 .30902 L
.42651 .30902 L
.42715 .30902 L
.42785 .30902 L
.42908 .30902 L
.43024 .30902 L
.43149 .30902 L
.43266 .30902 L
.43373 .30902 L
.43505 .30902 L
.43579 .30902 L
.43648 .30902 L
.43772 .30902 L
.43843 .30902 L
.43909 .30902 L
.44023 .30902 L
.44145 .30902 L
.44275 .30902 L
.44395 .30902 L
.44502 .30902 L
.44617 .30902 L
.44823 .30902 L
.44932 .30902 L
.45048 .30902 L
.45174 .30902 L
.45291 .30902 L
.45412 .30902 L
.45481 .30902 L
.45545 .30902 L
.45661 .30902 L
.45785 .30902 L
.45906 .30902 L
.4602 .30902 L
.46122 .30902 L
.46234 .30902 L
.46299 .30902 L
.46368 .30902 L
.4649 .30902 L
.46623 .30902 L
.46698 .30902 L
.46767 .30902 L
.46894 .30902 L
.4701 .30902 L
.47074 .30902 L
.47143 .30902 L
.47269 .30902 L
.47381 .30902 L
.47505 .30902 L
.47635 .30902 L
.47756 .30902 L
Mistroke
.47869 .30902 L
.47973 .30902 L
.48092 .30902 L
.48206 .30902 L
.49209 .30902 L
.4935 .30902 L
.4942 .30902 L
.49484 .30902 L
.49558 .30902 L
.49638 .30902 L
.4971 .30902 L
.49777 .30902 L
.49899 .30902 L
.49964 .30902 L
.50033 .30902 L
.50106 .30902 L
.50175 .30902 L
.50305 .30902 L
.50418 .30902 L
.50541 .30902 L
.50657 .30902 L
.50763 .30902 L
.5088 .30902 L
.51009 .30902 L
.51074 .30902 L
.51144 .30902 L
.51269 .30902 L
.51338 .30902 L
.51401 .30902 L
.51471 .30902 L
.51545 .30902 L
.51669 .30902 L
.5174 .30902 L
.51806 .30902 L
.51929 .30902 L
.52041 .30902 L
.52171 .30902 L
.52294 .30902 L
.54135 .30902 L
.5614 .30902 L
.56246 .30902 L
.5636 .30902 L
.56565 .30902 L
.56779 .30902 L
.56891 .30902 L
.57013 .30902 L
.57146 .30902 L
.57271 .30902 L
.57382 .30902 L
.57505 .30902 L
Mistroke
.57619 .30902 L
.5774 .30902 L
.57852 .30902 L
.57957 .30902 L
.58081 .30902 L
.58212 .30902 L
.58324 .30902 L
.58446 .30902 L
.58577 .30902 L
.58651 .30902 L
.58718 .30902 L
.58849 .30902 L
.58972 .30902 L
.59927 .30902 L
.62024 .30902 L
.62998 .30902 L
.64028 .30902 L
.64907 .30902 L
.65148 .30902 L
.65407 .30902 L
.65532 .30902 L
.65651 .30902 L
.65758 .30902 L
.65874 .30902 L
.65939 .30902 L
.66008 .30902 L
.66131 .30902 L
.66263 .30902 L
.66338 .30902 L
.66408 .30902 L
.66535 .30902 L
.6665 .30902 L
.66714 .30902 L
.66784 .30902 L
.6691 .30902 L
.67022 .30902 L
.67146 .30902 L
.67276 .30902 L
.67397 .30902 L
.6751 .30902 L
.67614 .30902 L
.67733 .30902 L
.67847 .30902 L
.67979 .30902 L
.68099 .30902 L
.68165 .30902 L
.68237 .30902 L
.68368 .30902 L
.6849 .30902 L
.68619 .30902 L
Mistroke
.68851 .30902 L
.69946 .30902 L
.70069 .30902 L
.70183 .30902 L
.70303 .30902 L
.70435 .30902 L
.70499 .30902 L
.70568 .30902 L
.70642 .30902 L
.70711 .30902 L
.70833 .30902 L
.70902 .30902 L
.70966 .30902 L
.71092 .30902 L
.71211 .30902 L
.71433 .30902 L
.71549 .30902 L
.71673 .30902 L
.71737 .30902 L
.71808 .30902 L
.71932 .30902 L
.72053 .30902 L
.72168 .30902 L
.72271 .30902 L
.72383 .30902 L
.72505 .30902 L
.72635 .30902 L
.72868 .30902 L
.73743 .30902 L
.7427 .30902 L
.74529 .30902 L
.74767 .30902 L
.74879 .30902 L
.74984 .30902 L
.75093 .30902 L
.75212 .30902 L
.75694 .30902 L
.77785 .30902 L
.77895 .30902 L
.7801 .30902 L
.78137 .30902 L
.78253 .30902 L
.78691 .30902 L
.79148 .30902 L
.79409 .30902 L
.79534 .30902 L
.79652 .30902 L
.7978 .30902 L
.79896 .30902 L
.80021 .30902 L
Mistroke
.80091 .30902 L
.80156 .30902 L
.80283 .30902 L
.80356 .30902 L
.80423 .30902 L
.80495 .30902 L
.8056 .30902 L
.80635 .30902 L
.80706 .30902 L
.80824 .30902 L
.80949 .30902 L
.81173 .30902 L
.81289 .30902 L
.81414 .30902 L
.81486 .30902 L
.81552 .30902 L
.81681 .30902 L
.81804 .30902 L
.81874 .30902 L
.81937 .30902 L
.82059 .30902 L
.82175 .30902 L
.82241 .30902 L
.8231 .30902 L
.82435 .30902 L
.82717 .30902 L
.83808 .30902 L
.84778 .30902 L
.85822 .30902 L
.86345 .30902 L
.86842 .30902 L
.87289 .30902 L
.87411 .30902 L
.87542 .30902 L
.87665 .30902 L
.87776 .30902 L
.87891 .30902 L
.88012 .30902 L
.88116 .30902 L
.88229 .30902 L
.88351 .30902 L
.88482 .30902 L
.88606 .30902 L
.88719 .30902 L
.88818 .30902 L
.88922 .30902 L
.89036 .30902 L
.89141 .30902 L
.89256 .30902 L
.89381 .30902 L
Mistroke
.89498 .30902 L
.89607 .30902 L
.89728 .30902 L
.89839 .30902 L
.89968 .30902 L
.90088 .30902 L
.90214 .30902 L
.9028 .30902 L
.90351 .30902 L
.90469 .30902 L
.90599 .30902 L
.90716 .30902 L
.90827 .30902 L
.90956 .30902 L
.91073 .30902 L
.91183 .30902 L
.91285 .30902 L
.91397 .30902 L
.91516 .30902 L
.91585 .30902 L
.91657 .30902 L
.91786 .30902 L
.91853 .30902 L
.91925 .30902 L
.92004 .30902 L
.92078 .30902 L
.92146 .30902 L
.9222 .30902 L
.9229 .30902 L
.92354 .30902 L
.92477 .30902 L
.92606 .30902 L
.92723 .30902 L
.92848 .30902 L
.93075 .30902 L
.93214 .30902 L
.93345 .30902 L
.93464 .30902 L
.93593 .30902 L
.93724 .30902 L
.93845 .30902 L
.93914 .30902 L
.93978 .30902 L
.94045 .30902 L
.94119 .30902 L
.94244 .30902 L
.94358 .30902 L
.94489 .30902 L
.94614 .30902 L
.94726 .30902 L
Mistroke
.94845 .30902 L
.94946 .30902 L
.95058 .30902 L
.95178 .30902 L
.95307 .30902 L
.9542 .30902 L
.95541 .30902 L
.95672 .30902 L
.95793 .30902 L
.95867 .30902 L
.95938 .30902 L
.96069 .30902 L
.96136 .30902 L
.96208 .30902 L
.96336 .30902 L
.96407 .30902 L
.96473 .30902 L
.96546 .30902 L
.96625 .30902 L
.96752 .30902 L
.9682 .30902 L
.96891 .30902 L
.97023 .30902 L
.97144 .30902 L
.97273 .30902 L
.97393 .30902 L
.97502 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{388, 239.6875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000640000l0800@400oooQOl00?ooQOl00?ooQOl0
05Ko00@003;o00@003Co00<<03Co00<l06So00<<01_o001Ho`03?00ao`03?00do`04?00do`03?00a
o`03000co`04?00Ko`00F?l00c`0<_l00c`0=_l00c`0;ol503Go00<l033o00@l01_o001Ho`03?00c
o`03?00co`03300ao`04?00fo`03?00`o`03000Lo`00F?l00c`0=?l00c`0=?l00c`0<?l00c00<ol0
0`00<ol00c`07?l005Ko00<003?o00@l03?o00@l03?o00<<03;o00<l03?o00<l01co001Ho`03?00b
o`03300do`03300do`03?00ao`03?00do`03000Ko`00ool`o`04001Ao`00oon5o`00oon5o`006?oo
06T000Co00008Ol00c`02?l00c`01ol00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l0
0c`02?l00c`01ol00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`01ol0
0c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`01ol00c`02?l00c`02?l0
0c`02?l00c`02?l00c`02?l00c`02?l00c`000Co00008Ol00c`02?l00c`01ol00c`02?l00c`02?l0
0c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`01ol00c`02?l00c`02?l00c`02?l00c`02?l0
0c`02?l00c`02?l00c`02?l00c`01ol00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l0
0c`02?l00c`01ol00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`02?l00c`000Co00008Ol0
0c`0<ol00c`0<ol00c`0=?l00c`0<ol00c`0=?l00c`0<ol00c`06_l0027o00<l0?ooHOl0027o00<l
0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l
0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l
0?ooHOl0027o00<l0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l
0?ooHOl0027o00<l0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l
0?ooHOl000So00<<00Ol00?000H?00<l00OloomPo`001ol013`02?l00c`01_l00c`01_?oof3o0007
o`04?009o`03?005o`04?`05`?ooH?l000Oo00@l00[o1Cl010l01ocoof3o0007o`04?00;o`04?007
o`03?03oof7o0007o`04?008o`04?006l`03o005coooH?l000So00<<00Wo00X?`307o?ooH?l0027o
00<l0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o
00<l0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o
00<l0?ooHOl0027o00<l0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o
00<l0?ooHOl0027o00<l0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o
00<l0?ooHOl000ko00<<00Ol1L000o`01Looof3o000=o`04?00;o`03?006loooH?l000go00@l00_o
00@o00G0oomPo`003Ol013`02?l00`001Ol00c`0oomQo`003Ol013`02?l00c`01Ol00c`0oomQo`00
3Ol013`02?l00c`01Ol00c`0oomQo`003_l00``02?l01@301ocoof3o000Qo`03303oof7o000Qo`03
?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03
303oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03
303oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03
?03oof7o000Qo`03303oof7o000Qo`03?03oof7o000Qo`03?03oof7o0008o`033007o0Kc1L000o`0
1Looof3o0007o`04?009o`03?005o`03?006loooH?l000Oo00@l00[o00@o00Ol1L3oof3o0007o`04
?00:o`Do00@?00OloomPo`001ol013`02ol013`01ol00c`0oomQo`001ol013`02?l013`01_<00o`0
1Looof3o0008o`033008o`030005?0033007o?ooH?l0027o00<l0?ooHOl0027o00<<0?ooHOl0027o
00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o
00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o
00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl0027o
00<l0?ooHOl0027o00<<0?ooHOl0027o00<l0?ooHOl0027o00<l0?ooHOl001Wo00D0`0OloomPo`00
6ol00c`01ocoof3o000Ko`06?o00o`1G00go000Ko`03?007o?ooH?l001_o00<l00OloomPo`006Ol0
0`001Ol00c`0oomQo`006ol00c`01ocoof3o000Qo`03?03oof7o000Qo`03303oof7o000Qo`03?03o
of7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03303oof7o000Qo`03?03o
of7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03303o
of7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03303o
of7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o0007o`030008?`03`0063`03?007
o?ooH?l000Wo00<l00Oo00<l00Ko00<l00KcoomPo`002Ol00c`02?l00c`01Ol013l01L3oof3o0009
o`03?009o`Do00@?00OloomPo`002Ol00c`02_l013`01ol00c`0oomQo`001ol00`002Ol013`01_<0
0o`01Looof3o0009o`03?008o`0:3l0`1ocoof3o000Qo`03303oof7o000Qo`03?03oof7o000Qo`03
?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03303oof7o000Qo`03
?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03303oof7o000Qo`03
?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03
303oof7o000Qo`03?03oof7o000Qo`03?03oof7o000=o`030008?`G000?l00G?oomPo`003ol00c`0
2_l00c`01_?oof3o000?o`03?00:o`03?006loooH?l000oo00<l00Oo00<000Go00<00?ooHOl000oo
00<l00Oo00<l00Go00<l0?ooHOl000go00<000Wo00<l00Go00<l0?ooHOl000oo00<l00Oo00D0`0Ol
oomPo`008Ol00c`0oomQo`008Ol00``0oomQo`008Ol00c`0oomQo`008Ol00c`0oomQo`008Ol00c`0
oomQo`008Ol00c`0oomQo`008Ol00c`0oomQo`008Ol00``0oomQo`008Ol00c`0oomQo`008Ol00c`0
oomQo`008Ol00c`0oomQo`008Ol00c`0oomQo`008Ol00``0oomQo`008Ol00c`0oomQo`008Ol00c`0
oomQo`008Ol00c`0oomQo`008Ol00c`0oomQo`008Ol00c`0oomQo`008Ol00``0oomQo`008Ol00c`0
oomQo`008Ol00c`0oomQo`001ol00`0023l6l`G000?l00G?oomPo`002Ol00c`02?l00c`01Ol00c`0
1_?oof3o0009o`03?009o`04?`07o0G0oomPo`002Ol00c`02Ol5?`043`07o?ooH?l000Wo00<l00[o
00@l00Oo00<l0?ooHOl000Oo00<000Wo00@l00Kc00?l00G?oomPo`002Ol00c`01ol00`001C`00``0
1ocoof3o000Qo`03?03oof7o000Qo`03303oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03
?03oof7o000Qo`03?03oof7o000Qo`03303oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03
?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03303oof7o000Qo`03?03oof7o000Qo`03
?03oof7o000Qo`03?03oof7o000Qo`03?03oof7o000Qo`03303oof7o000Qo`03?03oof7o000Qo`03
?03oof7o000Qo`03?03oof7o000Io`050<07o?ooH?l001Wo00<l00Go00<l0?ooHOl001[o00Hol005
`?ooH?l001_o00<l0?ooIol001co00<l0?ooI_l001Wo00@l0?ooJ?l001[o00<<0?ooJ?l00001\
\>"],
  ImageRangeCache->{{{0, 387}, {238.6875, 0}} -> {-0.609696, -0.11263, 
  0.018391, 0.009021}}]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase response", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Arg[H[E^\((I\ 2  Pi\ w)\), \ 0.5]]/Pi, 
      \ \ {w, \ \(-0.5\), \ 0.5}, \ PlotRange -> All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.294302 [
[.11905 .29652 -12 -9 ]
[.11905 .29652 12 0 ]
[.30952 .29652 -12 -9 ]
[.30952 .29652 12 0 ]
[.69048 .29652 -9 -9 ]
[.69048 .29652 9 0 ]
[.88095 .29652 -9 -9 ]
[.88095 .29652 9 0 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-0.4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-0.2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(0.2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(0.4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .59532 L
.10458 .58632 L
.14415 .57731 L
.18221 .56779 L
.22272 .55625 L
.26171 .54311 L
.30316 .5258 L
.34309 .50409 L
.3815 .47589 L
.42237 .43377 L
.46172 .3772 L
.49955 .30985 L
.53984 .23829 L
.57861 .18307 L
.61984 .141 L
.65954 .11231 L
.69774 .09181 L
.73838 .07489 L
.77751 .06171 L
.81909 .04991 L
.85916 .03994 L
.89771 .03121 L
.93871 .02247 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/P800@400i3o00<l08go002@o`03?02=
o`00R?l01@301ob<o`00R_l00c`01ob<o`00R_l013l01_23o`033006o`00P_l01@301o`6lgko1@09
o`00R_l00c`01oaio`D03_l008So00<000Go00<l07Go1@0Co`00R_l00c`01oa`o`04000Ho`00T?l0
0c`0K?l501co002@o`03?01Xo`04000Qo`00T?l00c`0Hol502Go002@o`03?01Oo`04000Zo`00T?l0
0``0Fol01000;_l0093o00<l05Oo00@003;o002@o`03?01Do`03000fo`00T?l00c`0D?l01000>Ol0
093o00<l04go00<003go002@o`03?01:o`030010o`00T?l00c`0Aol00`00@ol0093o00<l04Co00<0
04Ko002@o`033011o`030019o`00T?l00c`0?ol00``0Bol0093o00<l03co00<004ko002@o`03?00j
o`03301@o`00T?l00c`0=ol00`00Dol0093o00<l03Go00<<05Go002@o`03?00co`03301Go`00T?l0
0c`0<Ol00``0FOl0093o00<<033o00<l05[o002@o`03?00^o`03301Lo`00T?l00c`0;?l00``0G_l0
093o00<l02[o00<<063o002@o`03?00Yo`03?01Qo`00T?l00c`09ol00``0Hol0093o00<l02Ko00<l
06Co002@o`03?00Uo`03?01Uo`00T?l00c`08ol00``0Iol0093o00<<02;o00<l06So002@o`03?00Q
o`03?01Yo`00T?l00c`07ol00``0Jol0093o00<l01ko00<l06co002@o`03?00Mo`03?01]o`00T?l0
0c`07?l00c`0K_l007go00<<00Ol1L000o`01LlJo`03?01_o`00O?l013`02ol00c`01_<Io`03?01`
o`00O?l013`02ol00c`01_0Ho`03?01ao`00M_l010001O<00c`01_l00`001Ol00c`06?l00c`0L_l0
07co00@l00So00<l00Go00<l01Oo00<l07?o001lo`04?008o`03?005o`03?00Fo`03?01do`00OOl0
0``02?l01@301o`Do`03?01eo`00T?l00c`05?l00c`0M_l0093o00<l01?o00<l07Oo002@o`03?00C
o`03?01go`00T?l00c`04_l00c`0N?l0093o00<<017o00<l07Wo002@o`03?00Ao`03?01io`00T?l0
0c`04?l00c`0N_l0093o00<l00oo00<l07_o002@o`03?00>o`03?01lo`00T?l00c`03_l00c`0O?l0
093o00<l00go00<l07go002@o`03?00<o`03?01no`00T?l00``03?l00c`0O_l0093o00<l00_o00<l
07oo002@o`03?00:o`03?020o`00T?l00c`02_l00c`0P?l0093o00<l00Wo00<l087o002@o`03?008
o`03?022o`00T?l00c`02?l00c`0P_l0093o00<l00Oo00<l08?o002@o`03?006o`03?024o`00T?l0
0``01_l00c`0Q?l0093o00<l00Go00<l08Go002@o`03?005o`03?025o`00T?l013l01ob5o`00T?l0
13l01ob5o`00T?l00c`01ob6o`00T?l00c`01_>7o`007ol00``01o`7o2Go00<<00Ol00G002co00<l
00Kc9ol00``01o`01L009ol00``01o`7o1Wo000No`04?00:o`03?00Uo`04?008o`03?00]o`D?:_l0
13`02?l00c`09ol013`02_l00c`06_l001ko00@l00Oo1@0Vo`04?009o`03?00/o`Po9ol013`02Ol0
0c`09_l013`01ol501_o000Ho`040005l`03?005o`04?00Qo`040005l`03?008o`03?00[o`04?00[
o`04?00:o`03?00Uo`04?007o`04?00Lo`007_l013`02?l00c009ol013`02ol00c`0:_l013`0:ol0
13`02ol00c`09?l013`02?l00c007?l001ko00@l00Wo00<<02Ko00@l00So00@l02co00<`02co00@l
00So00@l02Ko00@l00Wo00<<01_o000Oo`03300:o`03?00Vo`033009o`03300/o`03300]o`033009
o`03300Wo`03300:o`03?00Jo`00T?l00``0SOl0093o00<l08go002@o`03?02=o`00o`0Q00001ol0
0c`02_l00c`02ol00c`02ol00c`02_l00c`02ol00c`02ol00c`02_l00c`02ol00c`02ol00c`02_l0
0``02ol00c`02ol00c`02ol00c`02_l00c`02ol00c`02ol00c`02_l00c`02ol00c`02ol00c`02_l0
0c`01Ol008ko00<`08oo002>o`03<02?o`00SOl013`0Sol008co23n<o`00S?l8?hco002;o`03?006
lhco002;o`03?006l8co002:o`03?007o8co002:o`03?007o8co0029o`04?`07o8co0029o`04?`07
o8co0028o`03?005o`03?02=o`00Qol00c`01_l00c`0SOl008Oo00<l00Ko00<l08go0026o`03?007
o`03302=o`00Q_l00c`01ol00c`0SOl008Go00<l00So00<l08go0025o`03?008o`03?02=o`00Q?l0
0c`02Ol00c`0SOl008?o00<l00[o00<l08go0022o`03?00;o`03?02=o`00P_l00c`02ol00c`0SOl0
087o00<l00co00<l08go0020o`03?00=o`03302=o`00P?l00c`03Ol00c`0SOl007oo00<l00ko00<l
08go001no`03?00?o`03?02=o`00O_l00c`03ol00c`0SOl007go00<l013o00<l08go001lo`03?00A
o`03?02=o`00O?l00c`04Ol00c`0SOl007_o00<l01;o00<<08go001jo`03?00Co`03?02=o`00NOl0
0c`05?l00c`0SOl007Wo00<l01Co00<l08go001ho`03?00Eo`03?02=o`00Mol00c`05_l00c`0SOl0
07Ko00Do`0K`1_<5`003o005chco001eo`04?`06o003?009o`03?006lhco001do`03?005o`04?00;
o`03?006lhco001co`03?006o`04?008o`030005o`03302=o`00L_l00c`01ol013`02?l00c`01Ol0
0c`0SOl0077o00<l00So00@l00So00<l00Go00<l08go001`o`03?00:o`033008o`050<07o8co001_
o`03?00No`03?02=o`00KOl00``08?l00c`0SOl006go00<l023o00<l08go001[o`03300Ro`03?02=
o`00J_l00c`08ol00``0SOl006So00<<02Go00<l08go001Wo`03?00Vo`03?02=o`00I_l00c`09ol0
0c`0SOl006Co00<<02Wo00<l08go001So`03?00Zo`03?02=o`00HOl00``0;?l00c`0SOl005oo00<<
02ko00<l08go001Mo`03300`o`03?02=o`00G?l00c`0<Ol00``0SOl005[o00<<03?o00<l08go001H
o`03300eo`03?02=o`00E_l00``0=ol00c`0SOl005?o00<003[o00<l08go001Ao`03300lo`03?02=
o`00Col00``0?_l00c`0SOl004co00<0047o00<l08go0019o`030014o`03302=o`00A_l00`00Aol0
0c`0SOl004?o00<004[o00<l08go0010o`03001=o`03?02=o`00?Ol00`00D?l00c`0SOl003Wo00@0
05?o00<l08go000fo`03001Go`03?02=o`00<_l01000F_l00c`0SOl002ko00@005ko00<l08go000Z
o`04001Ro`03302=o`009_l01000I_l00c`0SOl0027o1@1Zo`03?02=o`007Ol01000Kol00c`0SOl0
01So1@1co`03?02=o`004ol5073o00D0`0OlS?l000oo00@007Oo00<l00OlS?l000[o1@1ko`03?007
o8co0007o`030020o`04?`06l8co002:o`03?007o8co0028o`030005o`03?02=o`00R_l00c`01ob<
o`00T?l00c`0SOl00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.9375, 0}} -> {-0.526805, -1.041428, 
  0.003658, 0.011839}}]
}, Open  ]],

Cell[BoxData[
    \(phase[w_, \ g_]\  := \ 
      \(-w\)\  - \ 2\ ArcTan[g\ Sin[w]\ /\ \((1\  - \ g\ \ Cos[w])\)]\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[phase[2\ Pi\ w, \ 0.9]/Pi\ , \ {w, \ \(-0.5\), \ 0.5}, \ 
      PlotStyle -> 
        Sequence[\n\t\t\tThickness[0.015], \ RGBColor[0.4, \ 0, \ 0.0]], \n
      \t\t\ \ \ DefaultFont -> {"\<Times-Roman\>", \ 18}, \ Frame -> True]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 18  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.294302 [
[.11905 -0.0125 -19.5 -17 ]
[.11905 -0.0125 19.5 0 ]
[.30952 -0.0125 -19.5 -17 ]
[.30952 -0.0125 19.5 0 ]
[.5 -0.0125 -6.5 -17 ]
[.5 -0.0125 6.5 0 ]
[.69048 -0.0125 -13.5 -17 ]
[.69048 -0.0125 13.5 0 ]
[.88095 -0.0125 -13.5 -17 ]
[.88095 -0.0125 13.5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -26 -8.5 ]
[-0.0125 .01472 0 8.5 ]
[-0.0125 .16187 -39 -8.5 ]
[-0.0125 .16187 0 8.5 ]
[-0.0125 .30902 -13 -8.5 ]
[-0.0125 .30902 0 8.5 ]
[-0.0125 .45617 -27 -8.5 ]
[-0.0125 .45617 0 8.5 ]
[-0.0125 .60332 -13 -8.5 ]
[-0.0125 .60332 0 8.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
gsave
.11905 -0.0125 -80.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.437500 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.30952 0 m
.30952 .00625 L
s
gsave
.30952 -0.0125 -80.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.437500 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69048 0 m
.69048 .00625 L
s
gsave
.69048 -0.0125 -74.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88095 0 m
.88095 .00625 L
s
gsave
.88095 -0.0125 -74.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -87 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.437500 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .16187 m
.00625 .16187 L
s
gsave
-0.0125 .16187 -100 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.437500 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -74 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .45617 m
.00625 .45617 L
s
gsave
-0.0125 .45617 -88 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -74 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.4 0 0 r
.015 w
.02381 .60332 m
.06244 .60206 L
.10458 .60063 L
.14415 .59919 L
.18221 .59764 L
.22272 .59573 L
.26171 .59348 L
.28158 .5921 L
.30316 .59035 L
.34309 .58605 L
.36292 .5831 L
.38395 .57897 L
.39336 .57663 L
.40349 .57365 L
.42179 .56643 L
.43189 .56091 L
.44292 .55283 L
.44796 .54809 L
.45334 .54204 L
.46301 .52736 L
.46837 .51607 L
.4733 .50262 L
.47871 .48298 L
.48442 .454 L
.4894 .41895 L
.49404 .37602 L
.50459 .2565 L
.5096 .20751 L
.51504 .16729 L
.52019 .13989 L
.52495 .12114 L
.52922 .10811 L
.53394 .09674 L
.5435 .08016 L
.54842 .07388 L
.55359 .06839 L
.56285 .06065 L
.57281 .05438 L
.5837 .04912 L
.60332 .04232 L
.61429 .03947 L
.62427 .0373 L
.64507 .03366 L
.66425 .03106 L
.70271 .02718 L
.74212 .02431 L
.78 .02216 L
.82034 .02028 L
.85917 .01872 L
.90044 .01723 L
Mistroke
.94021 .01589 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{345, 213.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005I0000eQ000`40l00?003`ooooF_oo003ooomJ
ool00?oooe[oo`00ooooF_oo003ooomJool004coo`@03`Coo`803`Koo`803bOoo`@03`Coo`803`?o
o`L03bKoo`@03booo`@03`Coo`803`;oo`L03bKoo`@03`Coo`803`Ooo`803a_oo`00Booo0P0?0_oo
0P0?0ooo0P0?1_oo0P0?9_oo0P0?0_oo0P0?0ooo0P0?0ooo1`0?9Ooo0P0?0_oo0P0?;Ooo0P0?0_oo
0P0?0ooo0P0?0_oo1`0?9Ooo0P0?0_oo0P0?0ooo0P0?1ooo0P0?6ooo001;ool200l2ool200l;ool2
00lVool200l2ool200l9ool200l3ool00`0?ooooo`0Sool200l2ool200l]ool200l2ool200l8ool2
00l3ool00`0?ooooo`0Sool200l2ool200l<ool200lKool004[oo`803`Coo`803`Goo`P03bCoo`80
3`Coo`803`Woo`803bOoo`803`Coo`803b_oo`803`Coo`803`Soo`803bOoo`803`Coo`803`Koo`P0
3a[oo`00?_oo2@0?0ooo0P0?1?oo0P0?1Ooo0P0?0ooo0P0?6_oo2@0?0_oo0P0?1?oo0P0?2_oo0P0?
9_oo0P0?1?oo0P0?:ooo0P0?1?oo0P0?2Ooo0P0?9_oo0P0?1?oo0P0?1_oo0P0?0ooo0P0?6ooo001:
ool200l4ool200l5ool200l3ool200lUool200l4ool200l;ool200lUool200l4ool200l[ool200l4
ool200l:ool200lUool200l4ool200l6ool200l3ool200lKool004[oo`803`Coo`803`Koo`803`;o
o`803bGoo`803`Coo`803`_oo`803bGoo`803`Coo`803b_oo`803`Coo`803`[oo`803bGoo`803`Co
o`803`Ooo`803`;oo`803a_oo`00B_oo0P0?1?oo0P0?1_oo0`0?00?oo`0?00l09Ooo0P0?1?oo0P0?
3?oo0P0?9?oo0P0?1?oo0P0?:ooo0P0?1?oo0P0?2ooo0P0?9?oo0P0?1?oo0P0?1ooo0`0?00?oo`0?
00l06ooo001:ool200l4ool200l7ool200l00ooo00l03`0Uool200l4ool200l<ool200lTool200l4
ool200l[ool200l4ool200l;ool200lTool200l4ool200l8ool200l00ooo00l03`0Kool004[oo`80
3`Coo`803`Soo`@03bGoo`803`Coo`803`Ooo`0300oooooo00;oo`803bCoo`803`Coo`803b_oo`80
3`Coo`803`Koo`0300oooooo00;oo`803bCoo`803`Coo`803`Woo`@03a_oo`00Booo0P0?0_oo0P0?
2_oo0`0?9_oo0P0?0_oo0P0?2?oo0P0?0_oo0`0?9Ooo0P0?0_oo0P0?;Ooo0P0?0_oo0P0?1ooo0P0?
0_oo0`0?9Ooo0P0?0_oo0P0?2ooo0`0?6ooo001;ool200l2ool200l:ool300lVool200l2ool200l9
ool600lUool200l2ool200l]ool200l2ool200l8ool600lUool200l2ool200l;ool300lKool004co
o`@03`coo`803bOoo`@03`_oo`@03bOoo`@03booo`@03`[oo`@03bOoo`@03`goo`803a_oo`00oooo
F_oo003ooomJool00?oooe[oo`007Ooo1P0?oooo=ooo000Nool400l8oooo00l`00l001ooo`803`Wo
o`0300oooooo00Coo`0300oooooo00coo`0300oooooo00_oo`0300oooooo00coo`0300oooooo00_o
o`0300oooooo00_oo`0300oooooo00coo`0300oooooo00_oo`0300oooooo00coo`0300oooooo00_o
o`0300oooooo00_oo`0300oooooo00coo`0300oooooo00_oo`0300oooooo00_oo`0300oooooo00co
o`0300oooooo00_oo`0300oooooo00coo`0300oooooo00_oo`0300oooooo00_oo`0300oooooo00co
o`0300oooooo00_oo`0300oooooo00Coo`403`007ooo0P0?2Ooo00<03oooool08Ooo00<03oooool0
=ooo00<03oooool0=_oo00<03oooool0=ooo00<03oooool0=_oo00<03oooool05ooo160?1_oo0@0?
000@ool900l6ool200l9ool00`0?ooooo`2Dool00`0?ooooo`1]oolSH0l4ool100l001ooo`803`Wo
o`<03iCoo`0300oooooo05Gooc]P3`;oo`<03`007ooo0P0?2Ooo00<03oooool0U?oo00<03oooool0
A?ooC60?1?oo0@0?000Oool200l9ool00`0?ooooo`2Dool00`0?ooooo`0hoomHH0l4ool100l001oo
o`803`Woo`0300oooooo09Coo`0300oooooo02kooeaP3`[oo`403`007ooo0P0?2Ooo00<03oooool0
U?oo00<03oooool09oooAV0?9ooo0@0?000Mool400l9ool00`0?ooooo`2Dool00`0?ooooo`0Roolc
H0loool100l001koo`<03`Woo`0300oooooo09Coo`0300oooooo01koobIP3e3oo`403`007ooo0P0?
2Ooo00<03oooool0U?oo00<03oooool06ooo7F0?G?oo0@0?000Zool00`0?ooooo`2Dool00`0?oooo
o`0HoolFH0mVool100l002[oo`803iGoo`0300oooooo01Kooa5P3fcoo`803`00:_oo00<03oooool0
U?oo00<03oooool05?oo3V0?L_oo0@0?000Zool00`0?ooooo`2Dool00`0?ooooo`0Aool=H0mfool1
00l002[oo`0300oooooo09Coo`0300oooooo013oo`]P3gWoo`403`00:_oo00<03oooool0U?oo00<0
3oooool03ooo2F0?O?oo0@0?000Zool00`0?ooooo`2Dool00`0?ooooo`0>ool8H0mnool100l002[o
o`0300oooooo09Coo`0300oooooo00coo`QP3h3oo`403`00:_oo00<03oooool0U?oo00<03oooool0
3?oo1f0?POoo0@0?000Zool00`0?ooooo`2Dool00`0?ooooo`0:ool7H0n3ool100l002[oo`803iGo
o`0300oooooo00[oo`IP3h?oo`803`00:_oo00<03oooool0U?oo00<03oooool02Ooo1V0?QOoo0@0?
000Zool00`0?ooooo`2Dool00`0?ooooo`08ool6H0n6ool100l002[oo`0300oooooo09Coo`0300oo
oooo00Ooo`IP3hOoo`403`00:_oo00<03oooool0U?oo00<03oooool01ooo1V0?Qooo0@0?000Zool0
0`0?ooooo`2Dool00`0?ooooo`06ool6H0n8ool100l002[oo`0300oooooo09Coo`0300oooooo00Ko
o`IP3hSoo`403`00:_oo00<03oooool0U?oo00<03oooool01_oo1F0?ROoo0@0?000Zool00`0?oooo
o`2Dool00`0?ooooo`05ool6H0n9ool100l002[oo`803iGoo`0300oooooo00Goo`EP3hWoo`803`00
:_oo00<03oooool0U?oo00<03oooool01?oo1F0?Rooo0@0?000Zool00`0?ooooo`2Dool00`0?oooo
o`04ool5H0n;ool100l002[oo`0300oooooo09Coo`0300oooooo00Coo`EP3h_oo`403`00:_oo00<0
3oooool0U?oo00<03oooool00ooo1F0?S?oo0@0?000Zool00`0?ooooo`2Dool00`0?ooooo`03ool5
H0n<ool100l002[oo`0300oooooo09Coo`0300oooooo00?oo`EP3hcoo`403`00:_oo00<03oooool0
U?oo00<03oooool00_oo1F0?SOoo0@0?000Zool00`0?ooooo`2Dool00`0?ooooo`02ool5H0n=ool1
00l002[oo`803iGoo`0300oooooo00;oo`EP3hcoo`803`00:_oo00<03oooool0U?oo00<03oooool0
0_oo1F0?SOoo0@0?000Zool00`0?ooooo`2Dool0100?oooooooo1F0?S_oo0@0?000Zool00`0?oooo
o`2Dool0100?oooooooo1F0?S_oo0@0?000@ool400l4ool200l3ool400l9ool00`0?ooooo`2Dool0
100?oooooooo1F0?S_oo0@0?000?ool200l2ool200l3ool200l3ool200l01?oo00l03`0?1ooo00<0
3oooool0U?oo00@03oooooooo`EP3hkoo`403`003ooo0P0?0_oo0P0?3?oo0P0?1ooo00<03oooool0
U?oo00@03oooooooo`EP3hkoo`403`003_oo0P0?1?oo0P0?3?oo0P0?1_oo00<03oooool0U?oo00@0
3oooooooo`EP3hkoo`403`000ooo2@0?0_oo0P0?1?oo0P0?3?oo0P0?1_oo00<03oooool0U?oo00<0
3oooool01F0?Sooo0@0?000>ool200l4ool200l;ool300l6ool300nDool00`0?ooooo`05H0n=ool3
00l000koo`803`Coo`803`_oo`803`Ooo`0300oooooo09Coo`0300oooooo00EP3hooo`403`003_oo
0P0?1?oo0P0?2Ooo100?1ooo00<03oooool0U?oo00<03oooool01F0?Sooo0@0?000>ool200l4ool2
00l7ool400l9ool00`0?ooooo`2Dool00`0?ooooo`05H0n?ool100l000koo`803`Coo`803`Ooo`80
3`_oo`0300oooooo09Coo`0300oooooo00EP3hooo`403`003ooo0P0?0_oo0P0?2?oo0P0?2ooo00<0
3oooool0U?oo00<03oooH0l0160?T?oo0@0?000?ool200l2ool200l9ool500l7ool00`0?ooooo`2D
ool00`0?oomP3`04H0n@ool100l0013oo`@03`[oo`H03`Koo`0300oooooo09Coo`0300ooof0?00AP
3i3oo`403`00:_oo00<03oooool0U?oo00<03oooH0l0160?T?oo0@0?000Zool200nEool00`0?oomP
3`04H0n?ool200l002[oo`0300oooooo09Coo`0300ooof0?00AP3i3oo`403`00:_oo00<03oooool0
U?oo00<03oooH0l0160?T?oo0@0?000Zool00`0?ooooo`2Dool00`0?H0mP3`03H0nAool100l002[o
o`0300oooooo09Coo`0300mP3f0?00=P3i7oo`403`00:_oo00<03oooool0U?oo00<03f0?H0l00f0?
TOoo0@0?000Zool00`0?ooooo`2Dool00`0?H0mP3`03H0nAool100l002[oo`0300oooooo09Coo`03
00mP3f0?00=P3i7oo`403`00:_oo00<03oooool0U?oo00<03f0?H0l00f0?TOoo0@0?000Zool200nE
ool00`0?H0mP3`03H0n@ool200l002[oo`0300oooooo09Coo`0300mP3f0?00=P3i7oo`403`00:_oo
00<03oooool0U?oo00<03f0?H0l00f0?TOoo0@0?000Zool00`0?ooooo`2Dool5H0nBool100l002[o
o`0300oooooo09Coo`EP3i;oo`403`00:_oo00<03oooool0U?oo1F0?T_oo0@0?000Zool00`0?oooo
o`2Dool5H0nBool100l002[oo`0300oooooo09Coo`EP3i;oo`403`00:_oo00<03oooool0U?oo1F0?
T_oo0@0?000Zool200nEool5H0nAool200l002[oo`0300oooooo09Coo`EP3i;oo`403`00:_oo00<0
3oooool0U?oo1F0?T_oo0@0?000Zool00`0?ooooo`2Dool5H0nBool100l002[oo`0300oooooo09?o
o`EP3i?oo`403`00:_oo00<03oooool0Tooo1F0?Tooo0@0?000Zool00`0?ooooo`2Cool5H0nCool1
00l002[oo`0300oooooo09?oo`EP3i?oo`403`00:_oo0P0?U?oo1F0?T_oo0P0?000Zool00`0?oooo
o`2Cool5H0nCool100l002[oo`0300oooooo09?oo`EP3i?oo`403`00:_oo00<03oooool0Tooo1F0?
Tooo0@0?000Nool400l8ool00`0?ooooo`2Cool5H0nCool100l001goo`803`;oo`803`Ooo`0300oo
oooo09?oo`EP3i?oo`403`007Ooo0P0?0_oo0P0?1ooo00<03oooool0Tooo1F0?Tooo0@0?000Lool2
00l4ool200l6ool00`0?ooooo`2Cool5H0nCool100l001coo`803`Coo`803`Koo`0300oooooo09;o
o`EP3iCoo`403`007?oo0P0?1?oo0P0?1_ooU@0?1F0?U@0?000Lool200l4ool200l6ool00`0?oooo
o`2Bool5H0nDool100l001coo`803`Coo`803`Koo`0300oooooo09;oo`EP3iCoo`403`007?oo0P0?
1?oo0P0?1_oo00<03oooool0T_oo1F0?U?oo0@0?000Lool200l4ool200l6ool00`0?ooooo`2Bool5
H0nDool100l001goo`803`;oo`803`Ooo`0300oooooo09;oo`EP3iCoo`403`007Ooo0P0?0_oo0P0?
1ooo00<03oooool0T_oo1F0?U?oo0@0?000Nool400l8ool00`0?ooooo`2Bool5H0nDool100l002[o
o`0300oooooo09;oo`EP3iCoo`403`00:_oo0P0?Tooo1F0?Tooo0P0?000Zool00`0?ooooo`2Aool5
H0nEool100l002[oo`0300oooooo097oo`EP3iGoo`403`00:_oo00<03oooool0TOoo1F0?UOoo0@0?
000Zool00`0?ooooo`2Aool5H0nEool100l002[oo`0300oooooo097oo`EP3iGoo`403`00:_oo00<0
3oooool0TOoo1F0?UOoo0@0?000Zool00`0?ooooo`2Aool5H0nEool100l002[oo`0300oooooo097o
o`EP3iGoo`403`00:_oo0P0?T_oo1F0?U?oo0P0?000Zool00`0?ooooo`2Aool5H0nEool100l002[o
o`0300oooooo097oo`EP3iGoo`403`00:_oo00<03oooool0T?oo1F0?U_oo0@0?000Zool00`0?oooo
o`2@ool5H0nFool100l002[oo`0300oooooo093oo`EP3iKoo`403`00:_oo00<03oooool0T?oo1F0?
U_oo0@0?000Zool00`0?ooooo`2@ool5H0nFool100l002[oo`0300oooooo093oo`EP3iKoo`403`00
:_oo0P0?TOoo1F0?UOoo0P0?000Zool00`0?ooooo`2@ool5H0nFool100l002[oo`0300oooooo093o
o`EP3iKoo`403`00:_oo00<03oooool0T?oo1F0?U_oo0@0?000Zool00`0?ooooo`2?ool5H0l00`0?
ooooo`2Dool100l002[oo`0300oooooo08ooo`EP3`0300oooooo09Coo`403`00:_oo00<03oooool0
Sooo1F0?00<03oooool0U?oo0@0?000Zool00`0?ooooo`2?ool5H0l00`0?ooooo`2Dool100l002[o
o`0300oooooo08ooo`EP3`0300oooooo09Coo`403`00:_oo0P0?T?oo1F0?00<03oooool0Tooo0P0?
000Zool00`0?ooooo`2?ool5H0l00`0?ooooo`2Dool100l002[oo`0300oooooo08koo`EP3`03ool0
3ooo09Goo`403`00:_oo00<03oooool0S_oo1F0?00?oo`0?ool0UOoo0@0?000@ool400l4ool200l3
ool400l9ool00`0?ooooo`2>ool5H0l00ooo00ooo`2Eool100l000ooo`803`;oo`803`?oo`803`?o
o`803`04ool03`0?00l7ool00`0?ooooo`2>ool5H0l00ooo00ooo`2Eool100l000ooo`803`;oo`80
3`coo`803`Ooo`0300oooooo08koo`EP3`03ool03ooo09Goo`403`003_oo0P0?1?oo0P0?3?oo0P0?
1_oo00<03oooool0S_oo1F0?00?oo`0?ool0UOoo0@0?000>ool200l4ool200l<ool200l6ool00`0?
ooooo`2>ool5H0l00ooo00ooo`2Eool100l000koo`803`Coo`803`_oo`<03`Koo`<03hgoo`EP3`;o
o`0300oooooo09;oo`<03`003_oo0P0?1?oo0P0?2ooo0P0?1ooo00<03oooool0SOoo1F0?0_oo00<0
3oooool0U?oo0@0?000>ool200l4ool200l9ool400l7ool00`0?ooooo`2=ool5H0l2ool00`0?oooo
o`2Dool100l000koo`803`Coo`803`Ooo`@03`Woo`0300oooooo08goo`EP3`;oo`0300oooooo09Co
o`403`003_oo0P0?1?oo0P0?1ooo0P0?2ooo00<03oooool0SOoo1F0?0_oo00<03oooool0U?oo0@0?
000?ool200l2ool200l8ool200l;ool00`0?ooooo`2<ool5H0l3ool00`0?ooooo`2Dool100l000oo
o`803`;oo`803`Woo`D03`Ooo`0300oooooo08coo`EP3`?oo`0300oooooo09Coo`403`004?oo100?
2_oo1P0?1_oo00<03oooool0S?oo1F0?0ooo00<03oooool0U?oo0@0?000Zool00`0?ooooo`2<ool5
H0l3ool00`0?ooooo`2Dool100l002[oo`803hgoo`EP3`?oo`0300oooooo09?oo`803`00:_oo00<0
3oooool0Rooo1F0?1?oo00<03oooool0U?oo0@0?000Zool00`0?ooooo`2;ool5H0l4ool00`0?oooo
o`2Dool100l002[oo`0300oooooo08_oo`EP3`Coo`0300oooooo09Coo`403`00:_oo00<03oooool0
Rooo160?1Ooo00<03oooool0U?oo0@0?000Zool00`0?ooooo`2:ool5H0l5ool00`0?ooooo`2Dool1
00l002[oo`0300oooooo08[oo`EP3`Goo`0300oooooo09Coo`403`00:_oo00<03oooool0ROoo1F0?
1_oo00<03oooool0U?oo0@0?000Zool00`0?ooooo`29ool5H0l6ool00`0?ooooo`2Dool100l002[o
o`803h[oo`EP3`Koo`0300oooooo09?oo`803`00:_oo00<03oooool0R?oo1F0?1ooo00<03oooool0
U?oo0@0?000Zool00`0?ooooo`27ool6H0l7ool00`0?ooooo`2Dool100l002[oo`0300oooooo08Oo
o`EP3`Soo`0300oooooo09Coo`403`00:_oo00<03oooool0Q_oo1V0?2?oo00<03oooool0U?oo0@0?
000Zool00`0?ooooo`26ool6H0l8ool00`0?ooooo`2Dool100l002[oo`0300oooooo08Goo`IP3`Wo
o`0300oooooo09Coo`403`00:_oo00<03oooool0Q?oo1V0?2_oo00<03oooool0U?oo0@0?000Zool2
00n4ool7H0l:ool00`0?ooooo`2Cool200l002[oo`0300oooooo08;oo`MP3`_oo`0300oooooo09Co
o`403`00:_oo00<03oooool0POoo1f0?3?oo00<03oooool0U?oo0@0?000Zool00`0?ooooo`1oool8
H0l=ool00`0?ooooo`2Dool100l002[oo`0300oooooo07goo`UP3`koo`0300oooooo09Coo`403`00
:_oo00<03oooool0O?oo2F0?3ooo00<03oooool0U?oo0@0?000Zool00`0?ooooo`1jool:H0l@ool0
0`0?ooooo`2Dool100l002[oo`0300oooooo07Ooo`]P3a;oo`0300oooooo09Coo`403`00:_oo00<0
3oooool0Looo3V0?4ooo00<03oooool0U?oo0@0?000Zool200m_oolAH0lEool00`0?ooooo`2Cool2
00l002[oo`0300oooooo06Wooa=P3aSoo`0300oooooo09Coo`403`00:_oo00<03oooool0HOoo6F0?
6_oo00<03oooool0U?oo0@0?000Zool00`0?ooooo`1GoolPH0lMool00`0?ooooo`2Dool100l001ko
o`H03`Koo`0300oooooo04Soob]P3b7oo`0300oooooo09Coo`403`007ooo100?1ooo00<03oooool0
=Ooo>F0?9_oo00<03oooool0U?oo0@0?000Pool200l8ool00`0?ooooo`0Joom?H0l[ool00`0?oooo
o`2Dool100l0023oo`803`Soo`0300oooooo00CooeeP3c?oo`0300oooooo09Coo`403`008?oo0P0?
2?oo00<03oooool00oooE60??Ooo00<03oooool0U?oo0@0?000Pool200l8ool300l2oom6H0m<ool0
0`0?ooooo`2Bool300l0023oo`803`Soo`0300oooooo00?ooc9P3eooo`0300oooooo09Coo`403`00
8?oo0P0?2?oo00<03oooool00ooo5f0?N_oo00<03oooool0U?oo0@0?000Pool200l8ool00`0?oooo
o`0Qool00`0?ooooo`0gool00`0?ooooo`0fool00`0?ooooo`0gool00`0?ooooo`0fool00`0?oooo
o`0Qool100l0023oo`803`Soo`0300oooooo00Coo`0300oooooo00coo`0300oooooo00_oo`0300oo
oooo00coo`0300oooooo00_oo`0300oooooo00_oo`0300oooooo00coo`0300oooooo00_oo`0300oo
oooo00coo`0300oooooo00_oo`0300oooooo00_oo`0300oooooo00coo`0300oooooo00_oo`0300oo
oooo00_oo`0300oooooo00coo`0300oooooo00_oo`0300oooooo00coo`0300oooooo00_oo`0300oo
oooo00_oo`0300oooooo00coo`0300oooooo00_oo`0300oooooo00Coo`403`007_oo100?2?ooo`0?
<00?000Oool300oooolhool0023oo`803oooocSoo`00ooooF_oo003ooomJool00001\
\>"],
  ImageRangeCache->{{{0, 344}, {212.125, 0}} -> {-0.673683, -1.281369, 
  0.003476, 0.011248}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Group delay", "Subsection"],

Cell[BoxData[
    \(groupDelay[x_, \ w_]\  := \ \(-D[Evaluate[x], \ w]\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(groupDelay[phase[w, \ g], \ w]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\(-1\) + g\^2\)\/\(1 + g\^2 - 2\ g\ Cos[w]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[groupDelay[phase[2\ Pi\ w, \ 0.9], \ w]/\((2  Pi)\)], 
      \ {w, \ \(-0.5\), \ 0.5}, \ 
      PlotStyle -> 
        Sequence[\n\t\t\tThickness[0.008], \ RGBColor[0.4, \ 0, \ 0.0]], \ \n
      \t\ \ \ \ PlotRange -> {\(-1\), \ 21}, \ \n\t\ \ \ \ 
      AspectRatio -> 1/3, \ 
      FrameTicks -> {Automatic, \ Range[0, \ 20, \ \ 5], \ None, \ None}, \n
      \t\t\ \ \ DefaultFont -> {"\<Times-Roman\>", \ 18}, \ Frame -> True]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 18  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.015152 0.015152 [
[.11905 -0.0125 -19.5 -17 ]
[.11905 -0.0125 19.5 0 ]
[.30952 -0.0125 -19.5 -17 ]
[.30952 -0.0125 19.5 0 ]
[.5 -0.0125 -6.5 -17 ]
[.5 -0.0125 6.5 0 ]
[.69048 -0.0125 -13.5 -17 ]
[.69048 -0.0125 13.5 0 ]
[.88095 -0.0125 -13.5 -17 ]
[.88095 -0.0125 13.5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01515 -13 -8.5 ]
[-0.0125 .01515 0 8.5 ]
[-0.0125 .09091 -13 -8.5 ]
[-0.0125 .09091 0 8.5 ]
[-0.0125 .16667 -22 -8.5 ]
[-0.0125 .16667 0 8.5 ]
[-0.0125 .24242 -22 -8.5 ]
[-0.0125 .24242 0 8.5 ]
[-0.0125 .31818 -22 -8.5 ]
[-0.0125 .31818 0 8.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
gsave
.11905 -0.0125 -80.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.437500 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.30952 0 m
.30952 .00625 L
s
gsave
.30952 -0.0125 -80.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.437500 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69048 0 m
.69048 .00625 L
s
gsave
.69048 -0.0125 -74.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88095 0 m
.88095 .00625 L
s
gsave
.88095 -0.0125 -74.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01515 m
.00625 .01515 L
s
gsave
-0.0125 .01515 -74 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .09091 m
.00625 .09091 L
s
gsave
-0.0125 .09091 -74 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .16667 m
.00625 .16667 L
s
gsave
-0.0125 .16667 -83 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .24242 m
.00625 .24242 L
s
gsave
-0.0125 .24242 -83 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .31818 m
.00625 .31818 L
s
gsave
-0.0125 .31818 -83 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 .33333 L
s
0 .33333 m
1 .33333 L
s
1 0 m
1 .33333 L
s
.5 0 m
.5 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.4 0 0 r
.008 w
.02381 .01595 m
.02499 .01595 L
.02605 .01595 L
.02729 .01595 L
.02846 .01595 L
.03053 .01595 L
.03279 .01595 L
.03527 .01595 L
.0379 .01595 L
.04262 .01595 L
.04749 .01595 L
.05205 .01596 L
.06244 .01596 L
.07305 .01597 L
.08274 .01598 L
.10458 .01601 L
.12357 .01604 L
.14429 .01609 L
.16396 .01615 L
.18493 .01622 L
.20635 .01632 L
.22652 .01644 L
.24659 .0166 L
.26507 .01678 L
.28389 .01701 L
.30455 .01735 L
.32406 .01779 L
.34498 .01845 L
.35515 .01888 L
.36622 .01947 L
.37667 .02017 L
.38634 .02099 L
.39597 .02205 L
.405 .02333 L
.41492 .02521 L
.42045 .02657 L
.42561 .02809 L
.43518 .03188 L
.44024 .03459 L
.44565 .03828 L
.45133 .04338 L
.4567 .04986 L
.46152 .05768 L
.46675 .06932 L
.47164 .08465 L
.47621 .10477 L
.47883 .11975 L
.48123 .13619 L
.48662 .18443 L
.49179 .24287 L
Mistroke
.49451 .27267 L
.49601 .28613 L
.49674 .29154 L
.49742 .2957 L
.49807 .29889 L
.49876 .3013 L
.49945 .30269 L
.50021 .30298 L
.50152 .30047 L
.50273 .29484 L
.50398 .28621 L
.50512 .27627 L
.50766 .24918 L
.51245 .19427 L
.51694 .15073 L
.52163 .11691 L
.52411 .10312 L
.52679 .09084 L
.52954 .08048 L
.53242 .07157 L
.53759 .0594 L
.54235 .05122 L
.54756 .04456 L
.55286 .03947 L
.55786 .03578 L
.56721 .03079 L
.57245 .02875 L
.57728 .0272 L
.58818 .02456 L
.59789 .02288 L
.60698 .02169 L
.61694 .02069 L
.62763 .01986 L
.63779 .01924 L
.64885 .0187 L
.6584 .01833 L
.66896 .01798 L
.68871 .01748 L
.70971 .0171 L
.72903 .01684 L
.74988 .01663 L
.7699 .01647 L
.79099 .01634 L
.82906 .01617 L
.84865 .01611 L
.86959 .01606 L
.89091 .01602 L
.91106 .01599 L
.92076 .01598 L
.93105 .01597 L
Mistroke
.93983 .01596 L
.94949 .01596 L
.95621 .01595 L
.96236 .01595 L
.96575 .01595 L
.96754 .01595 L
.96945 .01595 L
.9704 .01595 L
.97128 .01595 L
.97215 .01595 L
.97295 .01595 L
.9737 .01595 L
.97451 .01595 L
.97531 .01595 L
.97619 .01595 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{575.6875, 191.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900000`1000`40l00?003`oooooooo@_oo003o
oooooom2ool00?oooooood;oo`00Jooo100?1?oo0P0?1ooo0P0?COoo100?1?oo0P0?0ooo1`0?C?oo
100?EOoo100?1?oo0P0?0ooo1`0?C?oo100?1?oo0P0?1_oo0P0?B_oo001Zool200l2ool200l3ool2
00l7ool200m<ool200l2ool200l3ool200l3ool700m;ool200l2ool200mCool200l2ool200l3ool2
00l3ool700m;ool200l2ool200l3ool200l6ool200m:ool006[oo`803`;oo`803`coo`803dcoo`80
3`;oo`803`Woo`803`?oo`0300oooooo04Woo`803`;oo`803e?oo`803`;oo`803`Woo`803`?oo`03
00oooooo04Woo`803`;oo`803`_oo`803d[oo`00JOoo0P0?1?oo0P0?1_oo200?B_oo0P0?1?oo0P0?
2Ooo0P0?COoo0P0?1?oo0P0?DOoo0P0?1?oo0P0?2Ooo0P0?COoo0P0?1?oo0P0?1Ooo200?BOoo001N
ool900l2ool200l4ool200l6ool200l3ool200m0ool900l2ool200l4ool200l:ool200m<ool200l4
ool200mAool200l4ool200l:ool200m<ool200l4ool200l5ool200l3ool200m:ool006Woo`803`Co
o`803`Koo`803`?oo`803d_oo`803`Coo`803`_oo`803d_oo`803`Coo`803e7oo`803`Coo`803`_o
o`803d_oo`803`Coo`803`Goo`803`?oo`803d[oo`00JOoo0P0?1?oo0P0?1ooo0P0?0_oo0P0?Booo
0P0?1?oo0P0?2ooo0P0?Booo0P0?1?oo0P0?DOoo0P0?1?oo0P0?2ooo0P0?Booo0P0?1?oo0P0?1_oo
0P0?0_oo0P0?B_oo001Yool200l4ool200l7ool300l00ooo00l03`1;ool200l4ool200l<ool200m:
ool200l4ool200mAool200l4ool200l<ool200m:ool200l4ool200l6ool300l00ooo00l03`1:ool0
06Woo`803`Coo`803`Soo`803`03ool03`0?04_oo`803`Coo`803`coo`803d[oo`803`Coo`803e7o
o`803`Coo`803`coo`803d[oo`803`Coo`803`Ooo`803`03ool03`0?04[oo`00JOoo0P0?1?oo0P0?
2Ooo100?Booo0P0?1?oo0P0?1ooo00<03oooool00_oo0P0?B_oo0P0?1?oo0P0?DOoo0P0?1?oo0P0?
1ooo00<03oooool00_oo0P0?B_oo0P0?1?oo0P0?2?oo100?B_oo001Zool200l2ool200l;ool300m<
ool200l2ool200l8ool200l2ool300m;ool200l2ool200mCool200l2ool200l8ool200l2ool300m;
ool200l2ool200l:ool300m:ool006[oo`803`;oo`803`_oo`<03dcoo`803`;oo`803`Woo`H03d_o
o`803`;oo`803e?oo`803`;oo`803`Woo`H03d_oo`803`;oo`803`[oo`<03d[oo`00Jooo100?3Ooo
0P0?COoo100?2ooo100?COoo100?EOoo100?2ooo100?COoo100?3?oo0P0?B_oo003ooooooom2ool0
0?oooooood;oo`00oooooooo@_oo003ooooooom2ool00?oooooood;oo`00oooooooo@_oo003ooooo
oom2ool003;oool03oT03aKoo`00<_oo00<03oooool02Ooo00<03oooool05Ooo00<03oooool05Ooo
00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo
00<03oooool05Ooo00<03oooool05?oo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo
00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo
00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool02Ooo00<03oooool05?oo
000bool00`0?ooooo`09ool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?oooo
o`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?oooo
o`0Dool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?oooo
o`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?oooo
o`0Eool00`0?ooooo`0Eool00`0?ooooo`09ool00`0?ooooo`0Dool002?oo`@03`_oo`0300oooooo
03Woo`0300oooooo05goo`0300oooooo05coo`0300oooooo05goo`0300oooooo05goo`0300oooooo
03Woo`0300oooooo01Coo`008_oo0P0?0_oo0P0?2_oo00<03oooool0n?oo00<03oooool0nOoo00<0
3oooool05?oo000Rool200l2ool200l:ool00`0?ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0D
ool0027oo`803`Coo`803`Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo01Coo`008Ooo
0P0?1?oo0P0?2Ooo00<03oooool02OooV60?Eooo00<03oooool0E_ooV60?2ooo00<03oooool05?oo
000Qool200l4ool200l9ool400l7oon`H0m0ool00`0?ooooo`0noonaH0l:ool00`0?ooooo`0Dool0
027oo`803`Coo`803`Woo`0300oooooo00SookaP3cCoo`0300oooooo03?ookaP3`[oo`0300oooooo
01Coo`008Ooo0P0?1?oo0P0?2Ooo00<03oooool02Ooo`F0?;_oo00<03oooool0;?oo`V0?2ooo00<0
3oooool05?oo000Qool200l4ool200l9ool00`0?ooooo`2Qool^H0lYool00`0?ooooo`0Xool^H0nS
ool00`0?ooooo`0Dool0027oo`803`Coo`803`Woo`0300oooooo0;Sooa]P3bGoo`0300oooooo02Co
oaYP3k_oo`0300oooooo01Coo`008_oo0P0?0_oo0P0?2_oo00<03oooool0a?oo4V0?8_oo00<03ooo
ool08Ooo4V0?a_oo00<03oooool05?oo000Rool200l2ool200l:ool00`0?ooooo`3:ool>H0lPool0
0`0?ooooo`0Oool=H0o=ool00`0?ooooo`0Dool002?oo`@03`_oo`0300oooooo0<ooo`]P3akoo`03
00oooooo01goo`]P3m7oo`0300oooooo01Coo`00<_oo00<03oooool0dooo2F0?7?oo00<03oooool0
6ooo2F0?eOoo00<03oooool05?oo000bool00`0?ooooo`3Fool8H0lJool00`0?ooooo`0Iool8H0oH
ool00`0?ooooo`0Dool003;oo`0300oooooo0=Soo`MP3aWoo`0300oooooo01Soo`MP3m[oo`0300oo
oooo01Coo`00<_oo00<03oooool0f_oo1V0?6?oo00<03oooool05ooo1V0?g?oo00<03oooool05?oo
000bool00`0?ooooo`3Kool6H0lGool00`0?ooooo`0Fool6H0oMool00`0?ooooo`0Dool003;oo`03
00oooooo0=goo`EP3aKoo`0300oooooo01Goo`EP3mooo`0300oooooo01Coo`00<_oo00<03oooool0
g_oo1F0?5Ooo00<03oooool05?oo1F0?h?oo00<03oooool05?oo000bool00`0?ooooo`3Oool5H0lD
ool00`0?ooooo`0Cool5H0oQool00`0?ooooo`0Dool003;oo`0300oooooo0>3oo`EP3a?oo`0300oo
oooo01;oo`EP3n;oo`0300oooooo01Coo`00<_oo00<03oooool0hOoo1F0?4_oo00<03oooool04_oo
160?hooo00<03oooool05?oo000bool00`0?ooooo`3Qool5H0lBool00`0?ooooo`0Aool5H0oSool0
0`0?ooooo`0Dool003;oo`0300oooooo0>;oo`EP3a7oo`0300oooooo017oo`AP3nCoo`0300oooooo
01Coo`00<_oo00<03oooool0h_oo1F0?4Ooo00<03oooool04?oo160?iOoo00<03oooool05?oo000b
ool00`0?ooooo`3Sool5H0l@ool00`0?ooooo`0?ool4H0oVool00`0?ooooo`0Dool003;oo`0300oo
oooo0>Coo`AP3a3oo`0300oooooo00ooo`AP3nKoo`0300oooooo01Coo`00<_oo00<03oooool0i?oo
160?4?oo00<03oooool03_oo160?iooo00<03oooool05?oo000bool00`0?ooooo`3Uool4H0l?ool0
0`0?ooooo`0>ool4H0oWool00`0?ooooo`0Dool003;oo`0300oooooo0>Goo`AP3`ooo`0300oooooo
00koo`AP3nOoo`0300oooooo01Coo`00<_oo00<03oooool0i_oo160?3_oo00<03oooool03Ooo160?
j?oo00<03oooool05?oo000bool00`0?ooooo`3Vool4H0l>ool00`0?ooooo`0=ool4H0oXool00`0?
ooooo`0Dool003;oo`0300oooooo0>Ooo`AP3`goo`0300oooooo00coo`AP3nWoo`0300oooooo01Co
o`00<_oo00<03oooool0iooo160?3Ooo00<03oooool03?oo160?jOoo00<03oooool05?oo000bool0
0`0?ooooo`3Wool4H0l=ool00`0?ooooo`0<ool4H0oYool00`0?ooooo`0Dool003;oo`0300oooooo
0>Soo`AP3`coo`0300oooooo00_oo`AP3n[oo`0300oooooo01Coo`00<_oo00<03oooool0j?oo160?
3?oo00<03oooool02ooo160?j_oo00<03oooool05?oo000Rool400l<ool00`0?ooooo`3Xool4H0l<
ool00`0?ooooo`0;ool4H0oZool00`0?ooooo`0Dool002;oo`803`04ool03`0?00l:ool00`0?oooo
o`3Xool5H0l;ool00`0?ooooo`0:ool4H0o[ool00`0?ooooo`0Dool002Koo`803`[oo`0300oooooo
0>Woo`AP3`_oo`0300oooooo00[oo`AP3n_oo`0300oooooo01Coo`009ooo0P0?2Ooo00<03oooool0
jOoo160?2ooo00<03oooool02_oo160?jooo00<03oooool05?oo000Wool200l9ool00`0?ooooo`3Y
ool4H0l;ool00`0?ooooo`0:ool4H0o[ool00`0?ooooo`0Dool002Koo`<03`Woo`@03nSoo`AP3`_o
o`0300oooooo00Woo`AP3ncoo`0300oooooo01Coo`009_oo0P0?2_oo00<03oooool0j_oo160?2_oo
00<03oooool02Ooo160?k?oo00<03oooool05?oo000Tool400l:ool00`0?ooooo`3Zool4H0l:ool0
0`0?ooooo`09ool4H0o/ool00`0?ooooo`0Dool002;oo`@03`coo`0300oooooo0>[oo`AP3`[oo`03
00oooooo00Woo`AP3ncoo`0300oooooo01Coo`008_oo0P0?3_oo00<03oooool0j_oo160?2_oo00<0
3oooool02?oo160?kOoo00<03oooool05?oo000Rool200l>ool00`0?ooooo`3[ool4H0l9ool00`0?
ooooo`08ool4H0o]ool00`0?ooooo`0Dool002?oo`D03`[oo`0300oooooo0>_oo`AP3`Woo`0300oo
oooo00Soo`AP3ngoo`0300oooooo01Coo`008ooo1P0?2Ooo00<03oooool0jooo160?2Ooo00<03ooo
ool02?oo160?kOoo00<03oooool05?oo000bool00`0?ooooo`3[ool4H0l9ool00`0?ooooo`08ool4
H0o]ool00`0?ooooo`0Dool003;oo`0300oooooo0>_oo`AP3`Woo`0300oooooo00Ooo`AP3nkoo`03
00oooooo01Coo`00<_oo00<03oooool0k?oo160?2?oo00<03oooool01ooo160?k_oo00<03oooool0
5?oo000bool00`0?ooooo`3/ool4H0l8ool00`0?ooooo`07ool4H0o^ool00`0?ooooo`0Dool003;o
o`0300oooooo0>coo`AP3`Soo`0300oooooo00Ooo`AP3nkoo`0300oooooo01Coo`00<_oo00<03ooo
ool0k?oo160?2?oo00<03oooool01ooo160?k_oo00<03oooool05?oo000bool00`0?ooooo`3/ool4
H0l8ool00`0?ooooo`07ool4H0o^ool00`0?ooooo`0Dool003;oo`0300oooooo0>coo`AP3`Soo`03
00oooooo00Koo`AP3nooo`0300oooooo01Coo`00<_oo00<03oooool0kOoo160?1ooo00<03oooool0
1_oo160?kooo00<03oooool05?oo000bool00`0?ooooo`3]ool4H0l7ool00`0?ooooo`06ool4H0o_
ool00`0?ooooo`0Dool003;oo`0300oooooo0>goo`AP3`Ooo`0300oooooo00Koo`AP3nooo`0300oo
oooo01Coo`00<_oo00<03oooool0kOoo160?1ooo00<03oooool01_oo160?kooo00<03oooool05?oo
000bool00`0?ooooo`3]ool4H0l7ool00`0?ooooo`06ool4H0o_ool00`0?ooooo`0Dool003;oo`03
00oooooo0>goo`AP3`Ooo`0300oooooo00Koo`AP3nooo`0300oooooo01Coo`00<_oo00<03oooool0
kOoo160?1ooo00<03oooool01_oo160?kooo00<03oooool05?oo000bool00`0?ooooo`3^ool4H0l6
ool00`0?ooooo`05ool4H0o`ool00`0?ooooo`0Dool003;oo`0300oooooo0>koo`AP3`Koo`0300oo
oooo00Goo`AP3o3oo`0300oooooo01Coo`00<_oo00<03oooool0k_oo160?1_oo00<03oooool01Ooo
160?l?oo00<03oooool05?oo000bool00`0?ooooo`3^ool4H0l6ool00`0?ooooo`05ool4H0o`ool0
0`0?ooooo`0Dool003;oo`0300oooooo0>koo`AP3`Koo`0300oooooo00Goo`AP3o3oo`0300oooooo
01Coo`00<_oo00<03oooool0k_oo160?1_oo00<03oooool01Ooo160?l?oo00<03oooool05?oo000b
ool00`0?ooooo`3^ool4H0l6ool00`0?ooooo`05ool4H0o`ool00`0?ooooo`0Dool003;oo`0300oo
oooo0>koo`AP3`Koo`0300oooooo00Coo`AP3o7oo`0300oooooo01Coo`00<_oo00<03oooool0k_oo
160?1_oo00<03oooool01?oo160?lOoo00<03oooool05?oo000bool00`0?ooooo`3_ool4H0l5ool0
0`0?ooooo`04ool4H0oaool00`0?ooooo`0Dool001[oo`H03`?oo`@03`_oo`0300oooooo0>ooo`AP
3`Goo`0300oooooo00Coo`AP3o7oo`0300oooooo01Coo`006ooo100?0ooo0P0?0_oo0P0?2_oo00<0
3oooool0kooo160?1Ooo00<03oooool01?oo160?lOoo00<03oooool05?oo000Lool200l4ool200l2
ool200l:ool00`0?ooooo`3_ool4H0l5ool00`0?ooooo`04ool4H0oaool00`0?ooooo`0Dool001co
o`803`?oo`803`Coo`803`Woo`0300oooooo0>ooo`AP3`Goo`0300oooooo00Coo`AP3o7oo`0300oo
oooo01Coo`007?oo0P0?0ooo0P0?1?oo0P0?2Ooo00<03oooool0kooo160?1Ooo00<03oooool01?oo
160?lOoo00<03oooool05?oo000Lool200l3ool200l4ool200l9ool400o^ool4H0l5ool00`0?oooo
o`04ool4H0oaool00`0?ooooo`0Dool001coo`803`?oo`803`Coo`803`Woo`0300oooooo0>ooo`AP
3`Goo`0300oooooo00?oo`AP3o;oo`0300oooooo01Coo`007?oo0P0?0ooo0P0?1?oo0P0?2Ooo00<0
3oooool0kooo160?1Ooo00<03oooool00ooo160?l_oo00<03oooool05?oo000Lool200l3ool200l4
ool200l9ool00`0?ooooo`3`ool4H0l4ool00`0?ooooo`03ool4H0obool00`0?ooooo`0Dool001co
o`803`?oo`803`Coo`803`Woo`0300oooooo0?3oo`AP3`Coo`0300oooooo00?oo`AP3o;oo`0300oo
oooo01Coo`006_oo100?1?oo0P0?0_oo0P0?2_oo00<03oooool0l?oo160?1?oo00<03oooool00ooo
160?l_oo00<03oooool05?oo000Kool300l4ool200l2ool200l:ool00`0?ooooo`3`ool4H0l4ool0
0`0?ooooo`03ool4H0obool00`0?ooooo`0Dool001coo`803`Goo`@03`_oo`0300oooooo0?3oo`AP
3`Coo`0300oooooo00?oo`AP3o;oo`0300oooooo01Coo`00<_oo00<03oooool0l?oo160?1?oo00<0
3oooool00ooo160?l_oo00<03oooool05?oo000bool00`0?ooooo`3`ool4H0l4ool00`0?ooooo`03
ool4H0obool00`0?ooooo`0Dool003;oo`0300oooooo0?3oo`AP3`Coo`0300oooooo00?oo`AP3o;o
o`0300oooooo01Coo`00<_oo00<03oooool0l?oo160?1?oo00<03oooool00_oo160?looo00<03ooo
ool05?oo000bool00`0?ooooo`3`ool4H0l4ool00`0?ooooo`02ool4H0ocool00`0?ooooo`0Dool0
03;oo`0300oooooo0?7oo`AP3`?oo`0300oooooo00;oo`AP3o?oo`0300oooooo01Coo`00<_oo00<0
3oooool0lOoo160?0ooo00<03oooool00_oo160?looo00<03oooool05?oo000bool00`0?ooooo`3a
ool4H0l3ool00`0?ooooo`02ool4H0ocool00`0?ooooo`0Dool003;oo`0300oooooo0?7oo`AP3`?o
o`0300oooooo00;oo`AP3o?oo`0300oooooo01Coo`00<_oo00<03oooool0lOoo160?0ooo00<03ooo
ool00_oo160?looo00<03oooool05?oo000bool00`0?ooooo`3aool4H0l3ool00`0?ooooo`02ool4
H0ocool00`0?ooooo`0Dool003;oo`0300oooooo0?7oo`AP3`?oo`0300oooooo00;oo`AP3o?oo`03
00oooooo01Coo`00<_oo00<03oooool0lOoo160?0ooo00<03oooool00_oo160?looo00<03oooool0
5?oo000bool00`0?ooooo`3aool4H0l3ool00`0?ooooo`02ool4H0ocool00`0?ooooo`0Dool003;o
o`0300oooooo0?7oo`AP3`?oo`0400ooooooool4H0odool00`0?ooooo`0Dool003;oo`0300oooooo
0?7oo`AP3`?oo`0400ooooooool4H0odool00`0?ooooo`0Dool003;oo`0300oooooo0?;oo`AP3`;o
o`0400ooooooool4H0odool00`0?ooooo`0Dool003;oo`0300oooooo0?;oo`AP3`;oo`0400oooooo
ool4H0odool00`0?ooooo`0Dool003;oo`0300oooooo0?;oo`AP3`;oo`0400ooooooool4H0odool0
0`0?ooooo`0Dool003;oo`0300oooooo0?;oo`AP3`;oo`0400ooooooool4H0odool00`0?ooooo`0D
ool003;oo`0300oooooo0?;oo`AP3`;oo`0400ooooooool4H0odool00`0?ooooo`0Dool003;oo`03
00oooooo0?;oo`AP3`;oo`0400ooooooool4H0odool00`0?ooooo`0Dool003;oo`0300oooooo0?;o
o`AP3`;oo`0400ooooooool4H0odool00`0?ooooo`0Dool003;oo`0300oooooo0?;oo`AP3`;oo`04
00ooooooool4H0odool00`0?ooooo`0Dool003;oo`0300oooooo0?;oo`AP3`;oo`0400ooooooool4
H0odool00`0?ooooo`0Dool001[oo`H03`;oo`@03`coo`0300oooooo0?;oo`AP3`;oo`0300oooooo
00AP3oGoo`0300oooooo01Coo`006ooo100?0ooo0P0?00Coo`0?00l03`[oo`0300oooooo0?;oo`AP
3`;oo`0300oooooo00AP3oGoo`0300oooooo01Coo`007?oo0P0?2?oo0P0?2_oo00<03oooool0looo
160?00Coo`0?ooooo`AP3oGoo`0300oooooo01Coo`007?oo0P0?2Ooo0P0?2Ooo00<03oooool0looo
160?00Coo`0?ooooo`AP3oGoo`0300oooooo01Coo`007?oo0P0?2Ooo0P0?2Ooo00<03oooool0looo
160?00Coo`0?ooooo`AP3oGoo`0300oooooo01Coo`007?oo0P0?2?oo0`0?2Ooo100?l_oo160?00Co
o`0?ooooo`AP3oGoo`0300oooooo01Coo`007?oo0P0?2?oo0P0?2_oo00<03oooool0looo160?00Co
o`0?ooooo`AP3oGoo`0300oooooo01Coo`007?oo0P0?1_oo100?2_oo00<03oooool0looo160?00Co
o`0?ooooo`AP3oGoo`0300oooooo01Coo`007?oo0P0?1?oo100?3?oo00<03oooool0looo160?00Co
o`0?ooooo`AP3oGoo`0300oooooo01Coo`007?oo0P0?1?oo0P0?3_oo00<03oooool0looo160?00Co
o`0?ooooo`AP3oGoo`0300oooooo01Coo`006_oo100?1?oo0P0?3_oo00<03oooool0looo160?00Co
o`0?ooooo`AP3oGoo`0300oooooo01Coo`006ooo0`0?1Ooo1@0?2_oo00<03oooool0looo160?00Co
o`0?ooooo`AP3oGoo`0300oooooo01Coo`007?oo0P0?1Ooo1P0?2Ooo00<03oooool0looo160?00?o
o`0?ool0160?m_oo00<03oooool05?oo000bool00`0?ooooo`3dool4H0l00`0?oomP3`03H0ofool0
0`0?ooooo`0Dool003;oo`0300oooooo0?Coo`AP3`0300ooof0?00=P3oKoo`0300oooooo01Coo`00
<_oo00<03oooool0m?oo160?00<03oooH0l00f0?m_oo00<03oooool05?oo000bool00`0?ooooo`3d
ool4H0l00`0?oomP3`03H0ofool00`0?ooooo`0Dool003;oo`0300oooooo0?Coo`AP3`0300ooof0?
00=P3oKoo`0300oooooo01Coo`00<_oo00<03oooool0m?oo160?00<03oooH0l00f0?m_oo00<03ooo
ool05?oo000bool00`0?ooooo`3dool4H0l00`0?oomP3`03H0ofool00`0?ooooo`0Dool003;oo`03
00oooooo0?Coo`AP3`0300ooof0?00=P3oKoo`0300oooooo01Coo`00<_oo00<03oooool0m?oo160?
00<03oooH0l00f0?m_oo00<03oooool05?oo000bool00`0?ooooo`3dool4H0l00`0?H0mP3`02H0og
ool00`0?ooooo`0Dool003;oo`0300oooooo0?Coo`AP3`0300mP3f0?009P3oOoo`0300oooooo01Co
o`00<_oo00<03oooool0mOoo260?mooo00<03oooool05?oo000bool00`0?ooooo`3eool8H0ogool0
0`0?ooooo`0Dool003;oo`0300oooooo0?Goo`QP3oOoo`0300oooooo01Coo`00<_oo00<03oooool0
mOoo260?mooo00<03oooool05?oo000bool00`0?ooooo`3eool8H0ogool00`0?ooooo`0Dool003;o
o`0300oooooo0?Goo`QP3oOoo`0300oooooo01Coo`00<_oo00<03oooool0mOoo1f0?n?oo00<03ooo
ool05?oo000bool00`0?ooooo`3fool6H0ohool00`0?ooooo`0Dool003;oo`0300oooooo0?Koo`IP
3oSoo`0300oooooo01Coo`00<_oo00<03oooool0m_oo1V0?n?oo00<03oooool05?oo000bool00`0?
ooooo`3fool6H0ohool00`0?ooooo`0Dool003;oo`0300oooooo0?Koo`EP3oWoo`0300oooooo01Co
o`00<_oo00<03oooool0mooo160?nOoo00<03oooool05?oo000bool00`0?ooooo`3hool00f0?oooo
o`3iool00`0?ooooo`0Dool001Woo`L03`?oo`@03`_oo`0300oooooo0?Soo`0300oooooo0?Woo`03
00oooooo01Coo`006Ooo1`0?0_oo0P0?0_oo0P0?2_oo00<03oooool0n?oo00<03oooool0nOoo00<0
3oooool05?oo000Jool200l3ool00`0?ooooo`0200l2ool200l:ool00`0?ooooo`3hool00`0?oooo
o`3iool00`0?ooooo`0Dool001_oo`803`Coo`803`Coo`803`Woo`0300oooooo0?Soo`0300oooooo
0?Woo`0300oooooo01Coo`007?oo0P0?0ooo0P0?1?oo0P0?2Ooo00<03oooool0n?oo00<03oooool0
nOoo00<03oooool05?oo000Mool200l2ool200l4ool200l9ool400ogool00`0?ooooo`3iool00`0?
ooooo`0Dool001goo`803`;oo`803`Coo`803`Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oo
oooo01Coo`007_oo0P0?00?oo`0?00l01?oo0P0?2Ooo00<03oooool0n?oo00<03oooool0nOoo00<0
3oooool05?oo000Nool200l00ooo00l03`04ool200l9ool00`0?ooooo`3hool00`0?ooooo`3iool0
0`0?ooooo`0Dool001Woo`0300oooooo00;oo`803`03ool03`0?00Coo`803`Woo`0300oooooo0?So
o`0300oooooo0?Woo`0300oooooo01Coo`006Ooo0P0?0_oo0`0?0_oo0P0?0_oo0P0?2_oo00<03ooo
ool0n?oo00<03oooool0nOoo00<03oooool05?oo000Jool600l2ool200l2ool200l:ool00`0?oooo
o`3hool00`0?ooooo`3iool00`0?ooooo`0Dool001_oo`@03`Coo`@03`_oo`0300oooooo0?Soo`03
00oooooo0?Woo`0300oooooo01Coo`00<_ooo`0?n@0?5_oo0000\
\>"],
  ImageRangeCache->{{{0, 574.6875}, {190.75, 0}} -> {-0.630575, -3.925475, 
  0.002089, 0.131275}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Evaluate[groupDelay[phase[2\ Pi\ w, \ \(-0.30\)], \ w]/\((2  Pi)\)], 
      \ {w, \ \(-0.5\), \ 0.5}, \ 
      PlotStyle -> 
        Sequence[\n\t\t\tThickness[0.008], \ RGBColor[0.4, \ 0, \ 0.0]], \ \n
      \t\ \ \ \ PlotRange -> {\(-0.05\), \ 1.05}, \ \n\t\ \ \ \ 
      AspectRatio -> 1/3, \ 
      FrameTicks -> {Automatic, \ Range[0, \ 1, \ 0.25], \ None, \ None}, \n
      \t\t\ \ \ DefaultFont -> {"\<Times-Roman\>", \ 18}, \ Frame -> True]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 18  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.015152 0.30303 [
[.11905 -0.0125 -19.5 -17 ]
[.11905 -0.0125 19.5 0 ]
[.30952 -0.0125 -19.5 -17 ]
[.30952 -0.0125 19.5 0 ]
[.5 -0.0125 -6.5 -17 ]
[.5 -0.0125 6.5 0 ]
[.69048 -0.0125 -13.5 -17 ]
[.69048 -0.0125 13.5 0 ]
[.88095 -0.0125 -13.5 -17 ]
[.88095 -0.0125 13.5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01515 -13 -8.5 ]
[-0.0125 .01515 0 8.5 ]
[-0.0125 .09091 -36 -8.5 ]
[-0.0125 .09091 0 8.5 ]
[-0.0125 .16667 -27 -8.5 ]
[-0.0125 .16667 0 8.5 ]
[-0.0125 .24242 -36 -8.5 ]
[-0.0125 .24242 0 8.5 ]
[-0.0125 .31818 -13 -8.5 ]
[-0.0125 .31818 0 8.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
gsave
.11905 -0.0125 -80.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.437500 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.30952 0 m
.30952 .00625 L
s
gsave
.30952 -0.0125 -80.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.437500 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69048 0 m
.69048 .00625 L
s
gsave
.69048 -0.0125 -74.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88095 0 m
.88095 .00625 L
s
gsave
.88095 -0.0125 -74.5 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01515 m
.00625 .01515 L
s
gsave
-0.0125 .01515 -74 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .09091 m
.00625 .09091 L
s
gsave
-0.0125 .09091 -97 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .16667 m
.00625 .16667 L
s
gsave
-0.0125 .16667 -88 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .24242 m
.00625 .24242 L
s
gsave
-0.0125 .24242 -97 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.75) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .31818 m
.00625 .31818 L
s
gsave
-0.0125 .31818 -74 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
63.000000 18.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 .33333 L
s
0 .33333 m
1 .33333 L
s
1 0 m
1 .33333 L
s
.5 0 m
.5 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.4 0 0 r
.008 w
.20524 .33333 m
.22428 .3077 L
.26248 .26761 L
.30312 .23555 L
.34225 .21306 L
.36366 .20361 L
.38383 .1963 L
.40221 .19086 L
.42239 .18611 L
.44232 .18257 L
.45322 .18111 L
.46339 .18002 L
.46839 .17959 L
.47384 .17919 L
.47864 .1789 L
.48374 .17866 L
.48832 .17849 L
.49093 .17843 L
.49212 .1784 L
.49338 .17838 L
.49445 .17836 L
.49562 .17835 L
.49668 .17834 L
.49767 .17833 L
.49884 .17832 L
.49991 .17832 L
.50114 .17832 L
.5023 .17833 L
.50345 .17834 L
.50469 .17835 L
.50586 .17836 L
.50693 .17838 L
.50954 .17844 L
.51202 .1785 L
.51694 .17868 L
.52231 .17895 L
.53189 .17961 L
.54076 .18043 L
.56133 .18314 L
.57995 .18659 L
.59923 .19125 L
.62006 .1976 L
.66112 .21472 L
.70066 .23813 L
.73868 .26868 L
.77916 .31185 L
s
.77916 .31185 m
.79485 .33333 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{575.6875, 191.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900000`1000`40l00?003`oooooooo@_oo003o
oooooom2ool00?oooooood;oo`00L_oo100?1?oo0P0?1ooo0P0?COoo100?1?oo0P0?0ooo1`0?C?oo
100?EOoo100?1?oo0P0?0ooo1`0?C?oo100?1?oo0P0?1_oo0P0?@ooo001aool200l2ool200l3ool2
00l7ool200m<ool200l2ool200l3ool200l3ool700m;ool200l2ool200mCool200l2ool200l3ool2
00l3ool700m;ool200l2ool200l3ool200l6ool200m3ool0077oo`803`;oo`803`coo`803dcoo`80
3`;oo`803`Woo`803`?oo`0300oooooo04Woo`803`;oo`803e?oo`803`;oo`803`Woo`803`?oo`03
00oooooo04Woo`803`;oo`803`_oo`803d?oo`00L?oo0P0?1?oo0P0?1_oo200?B_oo0P0?1?oo0P0?
2Ooo0P0?COoo0P0?1?oo0P0?DOoo0P0?1?oo0P0?2Ooo0P0?COoo0P0?1?oo0P0?1Ooo200?@_oo001U
ool900l2ool200l4ool200l6ool200l3ool200m0ool900l2ool200l4ool200l:ool200m<ool200l4
ool200mAool200l4ool200l:ool200m<ool200l4ool200l5ool200l3ool200m3ool0073oo`803`Co
o`803`Koo`803`?oo`803d_oo`803`Coo`803`_oo`803d_oo`803`Coo`803e7oo`803`Coo`803`_o
o`803d_oo`803`Coo`803`Goo`803`?oo`803d?oo`00L?oo0P0?1?oo0P0?1ooo0P0?0_oo0P0?Booo
0P0?1?oo0P0?2ooo0P0?Booo0P0?1?oo0P0?DOoo0P0?1?oo0P0?2ooo0P0?Booo0P0?1?oo0P0?1_oo
0P0?0_oo0P0?@ooo001`ool200l4ool200l7ool300l00ooo00l03`1;ool200l4ool200l<ool200m:
ool200l4ool200mAool200l4ool200l<ool200m:ool200l4ool200l6ool300l00ooo00l03`13ool0
073oo`803`Coo`803`Soo`803`03ool03`0?04_oo`803`Coo`803`coo`803d[oo`803`Coo`803e7o
o`803`Coo`803`coo`803d[oo`803`Coo`803`Ooo`803`03ool03`0?04?oo`00L?oo0P0?1?oo0P0?
2Ooo100?Booo0P0?1?oo0P0?1ooo00<03oooool00_oo0P0?B_oo0P0?1?oo0P0?DOoo0P0?1?oo0P0?
1ooo00<03oooool00_oo0P0?B_oo0P0?1?oo0P0?2?oo100?@ooo001aool200l2ool200l;ool300m<
ool200l2ool200l8ool200l2ool300m;ool200l2ool200mCool200l2ool200l8ool200l2ool300m;
ool200l2ool200l:ool300m3ool0077oo`803`;oo`803`_oo`<03dcoo`803`;oo`803`Woo`H03d_o
o`803`;oo`803e?oo`803`;oo`803`Woo`H03d_oo`803`;oo`803`[oo`<03d?oo`00L_oo100?3Ooo
0P0?COoo100?2ooo100?COoo100?EOoo100?2ooo100?COoo100?3?oo0P0?@ooo003ooooooom2ool0
0?oooooood;oo`00oooooooo@_oo003ooooooom2ool00?oooooood;oo`00oooooooo@_oo003ooooo
oom2ool003Woool03oT03`ooo`00>Ooo00<03oooool02Ooo00<03oooool05Ooo00<03oooool05Ooo
00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo
00<03oooool05Ooo00<03oooool05?oo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo
00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo
00<03oooool05Ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool02Ooo00<03oooool03Ooo
000iool00`0?ooooo`09ool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?oooo
o`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?oooo
o`0Dool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?oooo
o`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?ooooo`0Eool00`0?oooo
o`0Eool00`0?ooooo`0Eool00`0?ooooo`09ool00`0?ooooo`0=ool002[oo`@03`_oo`0300oooooo
03Woo`0300oooooo05goo`0300oooooo05coo`0300oooooo05goo`0300oooooo05goo`0300oooooo
03Woo`0300oooooo00goo`00:Ooo0P0?0_oo0P0?2_oo00<03oooool0n?oo00<03oooool0nOoo00<0
3oooool03Ooo000Yool200l2ool200l:ool00`0?ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0=
ool002Soo`803`Coo`803`Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00:?oo
0P0?1?oo0P0?2Ooo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000Xool200l4ool2
00l9ool400ogool00`0?ooooo`3iool00`0?ooooo`0=ool002Soo`803`Coo`803`Woo`0300oooooo
0?Soo`0300oooooo0?Woo`0300oooooo00goo`00:?oo0P0?1?oo0P0?2Ooo00<03oooool0n?oo00<0
3oooool0nOoo00<03oooool03Ooo000Xool200l4ool200l9ool00`0?ooooo`3hool00`0?ooooo`3i
ool00`0?ooooo`0=ool002Soo`803`Coo`803`Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oo
oooo00goo`00:Ooo0P0?0_oo0P0?2_oo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo
000Yool200l2ool200l:ool00`0?ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0=ool002[oo`@0
3`_oo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo00<03oooool0n?oo00<0
3oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0=
ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo00<03oooool0n?oo
00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3iool00`0?oooo
o`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo00<03oooool0
n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3iool00`0?
ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo00<03ooo
ool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3iool0
0`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo00<0
3oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3i
ool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo
00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?oooo
o`3iool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00
>Ooo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?
ooooo`3iool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00go
o`00>Ooo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool0
0`0?ooooo`3iool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo
00goo`00>Ooo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000Cool400l4ool200l3
ool700l2ool400l<ool00`0?ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0=ool001;oo`803`;o
o`803`?oo`803`?oo`L03`;oo`803`04ool03`0?00l:ool00`0?ooooo`3hool00`0?ooooo`3iool0
0`0?ooooo`0=ool001;oo`803`;oo`803`Woo`803`?oo`0300oooooo00Coo`803`[oo`0300oooooo
0?Soo`0300oooooo0?Woo`0300oooooo00goo`004Ooo0P0?1?oo0P0?2Ooo0P0?2_oo0P0?2Ooo00<0
3oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000Aool200l4ool200l:ool200l9ool200l9
ool00`0?ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0=ool0017oo`803`Coo`803`_oo`803`Oo
o`<03`Woo`@03oOoo`0300oooooo0?Woo`0300oooooo00goo`004Ooo0P0?1?oo0P0?2ooo0P0?1ooo
0P0?2_oo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000Aool200l4ool200l<ool2
00l4ool400l:ool00`0?ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0=ool0017oo`803`Coo`80
3`coo`803`;oo`@03`coo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`004Ooo0P0?
1?oo0P0?1ooo00<03oooool00_oo0P0?0_oo0P0?3_oo00<03oooool0n?oo00<03oooool0nOoo00<0
3oooool03Ooo000Bool200l2ool200l8ool200l2ool300l2ool200l>ool00`0?ooooo`3hool00`0?
ooooo`3iool00`0?ooooo`0=ool001;oo`803`;oo`803`Woo`H03`?oo`D03`[oo`0300oooooo0?So
o`0300oooooo0?Woo`0300oooooo00goo`004ooo100?2ooo100?1?oo1P0?2Ooo00<03oooool0n?oo
00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3iool00`0?oooo
o`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo00<03oooool0
n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3iool00`0?
ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo00<03ooo
ool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3iool0
0`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo00<0
3oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?ooooo`3i
ool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00>Ooo
00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?oooo
o`3iool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`00
>Ooo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool00`0?
ooooo`3iool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00go
o`00>Ooo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3hool0
0`0?ooooo`3iool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo
00goo`00>Ooo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?ooooo`3h
ool00`0?ooooo`3iool00`0?ooooo`0=ool003Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oo
oooo00goo`00>Ooo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000iool00`0?oooo
o`3hool00`0?ooooo`3iool00`0?ooooo`0=ool001coo`@03`Coo`803`?oo`@03`coo`0300oooooo
0?Soo`0300oooooo0?Woo`0300oooooo00goo`006ooo0P0?0_oo0P0?0ooo0P0?0ooo0P0?00Coo`0?
00l03`[oo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`006ooo0P0?0_oo0P0?3?oo
0P0?2_oo00<03oooool0n?oo00<03oooool0nOoo00<03oooool03Ooo000Jool200l4ool200l<ool2
00l9ool00`0?ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0=ool001[oo`803`Coo`803`coo`80
3`Woo`0300oooooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`006_oo0P0?1?oo0P0?2ooo0`0?
2Ooo100?mooo00<03oooool0nOoo00<03oooool03Ooo000Jool200l4ool200l;ool200l:ool00`0?
ooooo`3hool00`0?ooooo`3iool00`0?ooooo`0=ool001[oo`803`Coo`803`Woo`@03`[oo`0300oo
oooo0?Soo`0300oooooo0?Woo`0300oooooo00goo`006_oo0P0?1?oo0P0?1ooo100?3?oo00<03ooo
ool0n?oo00<03oooool0nOoo00<03oooool03Ooo000Jool200l4ool200l7ool200l>ool00`0?oooo
o`3^oolFH0o`ool00`0?ooooo`0=ool001_oo`803`;oo`803`Soo`803`koo`0300oooooo0>;oobeP
3nGoo`0300oooooo00goo`006ooo0P0?0_oo0P0?2Ooo1@0?2_oo00<03oooool0fooo?60?gOoo00<0
3oooool03Ooo000Lool400l:ool600l9ool00`0?ooooo`3Eoom8H0oGool00`0?ooooo`0=ool003Wo
o`0300oooooo0=3ooaiP3`[oo`0300oooooo00WooaiP3m;oo`0300oooooo00goo`00>Ooo00<03ooo
ool0c?oo5V0?5_oo00<03oooool05?oo5f0?c_oo00<03oooool03Ooo000iool00`0?ooooo`38oolC
H0lMool00`0?ooooo`0LoolCH0o:ool00`0?ooooo`0=ool003Woo`0300oooooo0<Cooa5P3b?oo`03
00oooooo02;ooa1P3lOoo`0300oooooo00goo`00>Ooo00<03oooool0`Ooo3f0?:?oo00<03oooool0
9ooo3f0?`ooo00<03oooool03Ooo000iool00`0?ooooo`2nool>H0l/ool00`0?ooooo`0[ool>H0o0
ool00`0?ooooo`0=ool003Woo`0300oooooo0;_oo`eP3c3oo`0300oooooo02ooo`eP3kgoo`0300oo
oooo00goo`00>Ooo00<03oooool0^?oo360?=?oo00<03oooool0<_oo360?^ooo00<03oooool03Ooo
000iool00`0?ooooo`2eool<H0lgool00`0?ooooo`0fool;H0nhool00`0?ooooo`0=ool003Woo`03
00oooooo0;?oo`]P3c[oo`0300oooooo03Woo`YP3kKoo`0300oooooo00goo`00>Ooo00<03oooool0
/Ooo2V0??Ooo00<03oooool0??oo2F0?]?oo00<03oooool03Ooo000iool00`0?ooooo`2^ool:H0m0
ool00`0?ooooo`0nool:H0naool00`0?ooooo`0=ool003Woo`0300oooooo0:coo`UP3d?oo`0300oo
oooo047oo`UP3jooo`0300oooooo00goo`00>Ooo00<03oooool0Z_oo2F0?AOoo00<03oooool0@ooo
2V0?[?oo00<03oooool03Ooo000iool00`0?ooooo`2Xool9H0m7ool00`0?ooooo`15ool:H0nZool0
0`0?ooooo`0=ool003Woo`0300oooooo0:Koo`QP3d[oo`0300oooooo04Soo`UP3jSoo`0300oooooo
00goo`00>Ooo00<03oooool0YOoo1f0?C?oo00<03oooool0B_oo260?Yooo00<03oooool03Ooo000i
ool00`0?ooooo`2Sool7H0m>ool00`0?ooooo`1=ool7H0nUool00`0?ooooo`0=ool003Woo`0300oo
oooo0:7oo`MP3e3oo`0300oooooo04ooo`MP3j?oo`0300oooooo00goo`00>Ooo00<03oooool0Wooo
1f0?D_oo00<03oooool0DOoo1V0?X_oo00<03oooool03Ooo000iool00`0?ooooo`2Nool7H0mCool0
0`0?ooooo`1Bool7H0nPool00`0?ooooo`0=ool003Woo`0300oooooo09coo`MP3eGoo`0300oooooo
05Coo`MP3ikoo`0300oooooo00goo`00>Ooo00<03oooool0V_oo1f0?Eooo00<03oooool0E_oo1V0?
WOoo00<03oooool03Ooo000iool00`0?ooooo`2Hool7H0mIool00`0?ooooo`1Gool7H0nKool00`0?
ooooo`0=ool003Woo`0300oooooo09Ooo`MP3e[oo`0300oooooo05Woo`MP3iWoo`0300oooooo00go
o`004ooo100?1?oo0P0?1?oo0P0?1_oo100?3?oo00<03oooool0UOoo1f0?G?oo00<03oooool0Fooo
1f0?Uooo00<03oooool03Ooo000Bool200l2ool200l3ool200l4ool200l6ool200l01?oo00l03`0?
2_oo00<03oooool0Tooo1f0?G_oo00<03oooool0G?oo1f0?U_oo00<03oooool03Ooo000Bool200l2
ool200l:ool00`0?ooooo`08ool200l:ool00`0?ooooo`2Bool6H0mPool00`0?ooooo`1Nool7H0nD
ool00`0?ooooo`0=ool0017oo`803`Coo`803`Woo`803`[oo`803`Woo`0300oooooo097oo`IP3f7o
o`0300oooooo063oo`IP3i?oo`0300oooooo00goo`004Ooo0P0?1?oo0P0?2Ooo0P0?2_oo0P0?2Ooo
00<03oooool0T?oo1V0?H_oo00<03oooool0H_oo1F0?T_oo00<03oooool03Ooo000Aool200l4ool2
00l:ool00`0?ooooo`07ool300l9ool400n=ool7H0mSool00`0?ooooo`1Rool7H0n@ool00`0?oooo
o`0=ool0017oo`803`Coo`803`[oo`803`Soo`803`[oo`0300oooooo08goo`IP3fGoo`0300oooooo
06Coo`IP3hooo`0300oooooo00goo`004Ooo0P0?1?oo0P0?2_oo0P0?1_oo100?2_oo00<03oooool0
S?oo1V0?I_oo00<03oooool0IOoo1V0?S_oo00<03oooool03Ooo000Aool200l4ool200l;ool00`0?
ooooo`02ool400l<ool00`0?ooooo`2:ool7H0mWool00`0?ooooo`1Vool6H0n=ool00`0?ooooo`0=
ool0017oo`803`Coo`803`_oo`803`?oo`803`koo`0300oooooo08Woo`MP3fSoo`0300oooooo06Oo
o`MP3h_oo`0300oooooo00goo`004_oo0P0?0_oo0P0?2?oo00<03oooool00_oo00@03oooooooo`80
3`koo`0300oooooo08Soo`IP3f[oo`0300oooooo06Woo`IP3h[oo`0300oooooo00goo`004_oo0P0?
0_oo0P0?2?oo1`0?0ooo1@0?2_oo00<03oooool0Qooo1V0?Jooo00<03oooool0J_oo1V0?ROoo00<0
3oooool03Ooo000Cool400l:ool600l3ool600l9ool00`0?ooooo`25ool7H0m/ool00`0?ooooo`1[
ool6H0n8ool00`0?ooooo`0=ool003Woo`0300oooooo08Coo`IP3fkoo`0300oooooo06coo`MP3hKo
o`0300oooooo00goo`00>Ooo00<03oooool0Pooo1V0?Kooo00<03oooool0K_oo1V0?QOoo00<03ooo
ool03Ooo000iool00`0?ooooo`22ool6H0m`ool00`0?ooooo`1_ool6H0n4ool00`0?ooooo`0=ool0
03Woo`0300oooooo083oo`MP3g7oo`0300oooooo073oo`IP3h?oo`0300oooooo00goo`00>Ooo00<0
3oooool0P?oo1F0?Looo00<03oooool0LOoo1V0?P_oo00<03oooool03Ooo000iool00`0?ooooo`1o
ool5H0mdool00`0?ooooo`1cool5H0n1ool00`0?ooooo`0=ool003Woo`0300oooooo07koo`EP3gGo
o`0300oooooo07Coo`EP3h3oo`0300oooooo00goo`00>Ooo00<03oooool0OOoo1F0?M_oo00<03ooo
ool0MOoo1F0?Oooo00<03oooool03Ooo000iool00`0?ooooo`1lool5H0mgool00`0?ooooo`1fool5
H0mnool00`0?ooooo`0=ool003Woo`0300oooooo07_oo`EP3gSoo`0300oooooo07Ooo`EP3ggoo`03
00oooooo00goo`00>Ooo00<03oooool0N_oo1F0?NOoo00<03oooool0N?oo1F0?O?oo00<03oooool0
3Ooo000iool00`0?ooooo`1iool5H0mjool00`0?ooooo`1iool5H0mkool00`0?ooooo`0=ool003Wo
o`0300oooooo07Soo`EP3g_oo`0300oooooo07[oo`EP3g[oo`0300oooooo00goo`00>Ooo00<03ooo
ool0Mooo1F0?O?oo00<03oooool0Nooo1F0?NOoo00<03oooool03Ooo000iool00`0?ooooo`1fool5
H0mmool00`0?ooooo`1lool5H0mhool00`0?ooooo`0=ool003Woo`0300oooooo07Goo`EP3gkoo`03
00oooooo07goo`EP3gOoo`0300oooooo00goo`00>Ooo00<03oooool0M?oo1F0?Oooo00<03oooool0
O_oo1F0?M_oo00<03oooool03Ooo000iool00`0?ooooo`1cool5H0n0ool00`0?ooooo`1oool5H0me
ool00`0?ooooo`0=ool003Woo`0300oooooo07;oo`EP3h7oo`0300oooooo083oo`EP3gCoo`0300oo
oooo00goo`00>Ooo00<03oooool0LOoo1F0?P_oo00<03oooool0P?oo1F0?M?oo00<03oooool03Ooo
000iool00`0?ooooo`1`ool5H0n3ool00`0?ooooo`21ool5H0mcool00`0?ooooo`0=ool003Woo`03
00oooooo06ooo`EP3hCoo`0300oooooo08;oo`EP3g;oo`0300oooooo00goo`00>Ooo00<03oooool0
K_oo1F0?QOoo00<03oooool0Pooo1F0?LOoo00<03oooool03Ooo000iool00`0?ooooo`1]ool5H0n6
ool00`0?ooooo`24ool5H0m`ool00`0?ooooo`0=ool003Woo`0300oooooo06coo`IP3hKoo`0300oo
oooo08Goo`EP3fooo`0300oooooo00goo`00:_oo1P0?2Ooo00<03oooool0K?oo1F0?Qooo00<03ooo
ool0Q_oo1F0?K_oo00<03oooool03Ooo000[ool400l:ool00`0?ooooo`1[ool5H0n8ool00`0?oooo
o`27ool5H0m]ool00`0?ooooo`0=ool002coo`803`_oo`0300oooooo06[oo`EP3hWoo`0300oooooo
08Soo`EP3fcoo`0300oooooo00goo`00;?oo0P0?2ooo00<03oooool0JOoo1F0?R_oo00<03oooool0
ROoo1F0?Jooo00<03oooool03Ooo000/ool200l;ool00`0?ooooo`1Yool5H0n:ool00`0?ooooo`29
ool5H0m[ool00`0?ooooo`0=ool002coo`803`_oo`@03fOoo`EP3h_oo`0300oooooo08[oo`EP3f[o
o`0300oooooo00goo`00;?oo0P0?2ooo00<03oooool0Iooo1F0?S?oo00<03oooool0Rooo1F0?JOoo
00<03oooool03Ooo000/ool200l;ool00`0?ooooo`1Vool5H0n=ool00`0?ooooo`2<ool5H0mXool0
0`0?ooooo`0=ool002coo`803`_oo`0300oooooo06Koo`EP3hgoo`0300oooooo08coo`EP3fSoo`03
00oooooo00goo`00;?oo0P0?2ooo00<03oooool0IOoo1F0?S_oo00<03oooool0SOoo1F0?Iooo00<0
3oooool03Ooo000Zool400l;ool00`0?ooooo`1Tool5H0n?ool00`0?ooooo`2>ool5H0mVool00`0?
ooooo`0=ool002_oo`<03`_oo`0300oooooo06?oo`EP3i3oo`0300oooooo08koo`EP3fKoo`0300oo
oooo00goo`00;?oo0P0?2ooo00<03oooool0Hooo1F0?T?oo00<03oooool0Sooo1F0?IOoo00<03ooo
ool03Ooo000ioomV00l4H0oo00lU00l4H0mV00l?ool00001\
\>"],
  ImageRangeCache->{{{0, 574.6875}, {190.75, 0}} -> {-0.645195, -0.19628, 
  0.002089, 0.006564}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 1213}, {0, 1024}},
WindowSize->{743, 838},
WindowMargins->{{Automatic, 58}, {Automatic, 66}},
Magnification->1
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 59, 0, 136, "Title"],

Cell[CellGroupData[{
Cell[1815, 55, 40, 0, 43, "Subsection"],
Cell[1858, 57, 125, 3, 25, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2020, 65, 40, 0, 27, "Subsection"],

Cell[CellGroupData[{
Cell[2085, 69, 112, 2, 25, "Input"],
Cell[2200, 73, 19042, 970, 248, 13376, 896, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[21257, 1046, 26, 0, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21320, 1051, 36, 0, 27, "Subsection"],

Cell[CellGroupData[{
Cell[21381, 1055, 137, 2, 25, "Input"],
Cell[21521, 1059, 7688, 281, 186, 2968, 218, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[29224, 1343, 129, 3, 25, "Input"],

Cell[CellGroupData[{
Cell[29378, 1350, 277, 5, 51, "Input"],
Cell[29658, 1357, 23220, 782, 222, 10840, 625, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[52927, 2145, 33, 0, 27, "Subsection"],
Cell[52963, 2147, 85, 1, 25, "Input"],

Cell[CellGroupData[{
Cell[53073, 2152, 79, 1, 25, "Input"],
Cell[53155, 2155, 89, 1, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53281, 2161, 486, 9, 93, "Input"],
Cell[53770, 2172, 24725, 678, 200, 9518, 486, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78532, 2855, 504, 10, 93, "Input"],
Cell[79039, 2867, 23394, 607, 200, 8435, 418, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

